package com.css.simulation.resource.common.controller;

import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.constants.DictConstants;
import api.common.pojo.param.MinioParameter;
import api.common.util.FileUtil;
import api.common.util.ObjectUtil;
import api.common.util.TimeUtil;
import com.css.simulation.resource.common.configuration.minio.SubMinioClient;
import com.css.simulation.resource.common.util.MinioUtil;
import io.minio.*;
import io.minio.errors.*;
import io.minio.http.Method;
import io.minio.messages.Item;
import io.minio.messages.Part;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.util.*;

@RestController
@RequestMapping("/minio")
public class MinioController {

    @Resource(name = "minioClientPrivate")
    private SubMinioClient minioClientPrivate;

    @Resource(name = "minioClientPublic")
    private SubMinioClient minioClientPublic;

    @Value("${minio.bucket-name}")
    private String bucketName;

    @Autowired
    RedisController redisController;


    @PostMapping("/hello")
    public String hello() {
        return "hello minio!";
    }

    @PostMapping(value = "/upload", consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
    public ResponseBodyVO<String> upload(
            @RequestPart("file") MultipartFile file,
            @RequestParam("objectName") String objectName//  "/xx/xxx/x/xx"
    ) throws ServerException, InsufficientDataException, ErrorResponseException, IOException, NoSuchAlgorithmException, InvalidKeyException, InvalidResponseException, XmlParserException, InternalException {
        MinioUtil.uploadFromMultipartFile(
                minioClientPrivate,
                file,
                bucketName,
                objectName
        );
        String previewUrl = MinioUtil.getPreviewUrl(minioClientPrivate, Method.GET, bucketName, objectName);

        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS, "请求成功！", previewUrl);
    }


    @PostMapping(value = "/uploadProcessBar", consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
    public ResponseBodyVO<String> uploadProcessBar(
            @RequestPart("file") MultipartFile file,
            HttpServletRequest request
    ) throws ServerException, InsufficientDataException, ErrorResponseException, IOException, NoSuchAlgorithmException, InvalidKeyException, InvalidResponseException, XmlParserException, InternalException {
        String type = request.getParameter("type");
        String objectPath = request.getParameter("objectPath");
        if (file != null) {
            String objectName = "";
            Integer nowTime = TimeUtil.getRq(new Date(), 0);
            if (type.equals(DictConstants.ALGORITHM_FILE)) {
                objectName = "algorithm/" + nowTime + "/" + objectPath + "/" + file.getOriginalFilename();
            }

            MinioUtil.uploadProcessBar(
                    minioClientPrivate,
                    file,
                    bucketName,
                    objectName,
                    objectPath,
                    redisController
            );
            Map map = new HashMap();
            map.put("fileName", objectName);

            return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS, map);
        }
        return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "文件流file为空，请检查！");
    }

    @PostMapping("/list")
    public ResponseBodyVO<List<String>> list(
            @RequestBody @Validated MinioParameter minioParameter
    ) throws ServerException, InsufficientDataException, ErrorResponseException, IOException, NoSuchAlgorithmException, InvalidKeyException, InvalidResponseException, XmlParserException, InternalException {

        List<String> objects = MinioUtil.listObjects(minioClientPrivate, bucketName, minioParameter.getObjectName());
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS, objects);
    }

    @PostMapping("/listDeepOne")
    public ResponseBodyVO<List<String>> listDeepOne(
            @RequestBody @Validated MinioParameter minioParameter
    ) throws Exception {
        List<String> objects = MinioUtil.listObjectsUnRecursive(minioClientPrivate, bucketName, minioParameter.getObjectName());
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS, objects);
    }

    @PostMapping("/download")
    public void download(
            @RequestBody @Validated MinioParameter minioParameter,
            HttpServletResponse response
    ) throws ServerException, InsufficientDataException, ErrorResponseException, IOException, NoSuchAlgorithmException, InvalidKeyException, InvalidResponseException, XmlParserException, InternalException {
        InputStream inputStream = MinioUtil.downloadToStream(
                minioClientPrivate,
                bucketName,
                minioParameter.getObjectName()
        );
        String fileName = FileUtil.getFileName(minioParameter.getObjectName());
        FileUtil.downloadForHttp(fileName, inputStream, response, 1024);
    }

    @RequestMapping("/preview")
    public void preview(@RequestParam("objectName") String objectName, HttpServletResponse response ) throws ServerException, InsufficientDataException, ErrorResponseException, IOException, NoSuchAlgorithmException, InvalidKeyException, InvalidResponseException, XmlParserException, InternalException {
        InputStream inputStream = MinioUtil.downloadToStream(
                minioClientPrivate,
                bucketName,
                objectName
        );
        String fileName = FileUtil.getFileName(objectName);
        FileUtil.downloadForHttp(fileName, inputStream, response, 1024);
    }

    @RequestMapping("/getPreviewUrl")
    public ResponseBodyVO<String> getPreviewUrl(@RequestBody @Validated MinioParameter minioParameter) throws ServerException, InsufficientDataException, ErrorResponseException, IOException, NoSuchAlgorithmException, InvalidKeyException, InvalidResponseException, XmlParserException, InternalException {
        String previewUrl = MinioUtil.getPreviewUrl(minioClientPublic, Method.GET, bucketName, minioParameter.getObjectName());
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS,"请求成功！", previewUrl);
    }

    @RequestMapping("/createMultipartUpload")
    @ResponseBody
    public ResponseBodyVO createMultipartUpload(@RequestBody Map<String, String> paramMap) throws Exception {
        String objectName = paramMap.get("objectName");
        String chunkSize = paramMap.get("chunkSize");
        String type = paramMap.get("type");
        if (ObjectUtil.isNull(objectName) || ObjectUtil.isNull(chunkSize) || ObjectUtil.isNull(type)) {
            return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "请求参数缺失！");
        }
        Integer nowTime = TimeUtil.getRq(new Date(), 0);
        if (type.equals(DictConstants.ALGORITHM_FILE)) {
            objectName = "algorithm/" + nowTime + "/" + objectName;
        }
        Map<String, Object> result = new HashMap<>();//结果数据
        CreateMultipartUploadResponse multipartUpload = minioClientPrivate.createMultipartUpload(bucketName, null, objectName, null, null);
        String uploadId = multipartUpload.result().uploadId();
        List<String> UrlList = new LinkedList<>();
        Map<String, String> queryParam = new HashMap<>();
        queryParam.put("uploadId", uploadId);
        int size = Integer.parseInt(chunkSize);
        for (int i = 1; i <= size; i++) {
            queryParam.put("partNumber", String.valueOf(i));
            String presignedObjectUrl = minioClientPublic.getPresignedObjectUrl(GetPresignedObjectUrlArgs.builder()
                    .method(Method.PUT)
                    .bucket(bucketName)
                    .object(objectName)
                    .expiry(60 * 60)//上传URL有效期
                    .extraQueryParams(queryParam)
                    .build());
            UrlList.add(presignedObjectUrl);
        }
        result.put("uploadId", uploadId);
        result.put("uploadUrls", UrlList);
        result.put("objectName", objectName);
        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS, result);
    }

    @RequestMapping("/completeMultipartUpload")
    @ResponseBody
    public ResponseBodyVO completeMultipartUpload(@RequestBody Map<String, String> paramMap) throws Exception {
        String objectName = paramMap.get("objectName");
        String uploadId = paramMap.get("uploadId");
        if (ObjectUtil.isNull(objectName) || ObjectUtil.isNull(uploadId)) {
            return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "请求参数缺失！");
        }
        ListPartsResponse listPartsResponse = minioClientPrivate.listParts(bucketName, null, objectName, 10000, 0, uploadId, null, null);
        List<Part> parts = listPartsResponse.result().partList();
        Part[] partArr = new Part[parts.size()];
        int partNumber = 1;
        for (Part part : parts) {
            partArr[partNumber - 1] = new Part(partNumber, part.etag());
            partNumber++;
        }
        minioClientPrivate.completeMultipartUpload(bucketName, null, objectName, uploadId, partArr, null, null);
        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS, "合并成功！");
    }
    @PostMapping("/remove")
    public void download(
            @RequestBody @Validated MinioParameter minioParameter
    ) throws ServerException, InsufficientDataException, ErrorResponseException, IOException, NoSuchAlgorithmException, InvalidKeyException, InvalidResponseException, XmlParserException, InternalException {

        MinioUtil.removeObject(minioClientPrivate, bucketName, minioParameter.getObjectName());
    }

}
