package com.css.simulation.resource.scheduler.consumer;


import api.common.pojo.constants.DictConstants;
import api.common.pojo.dto.ProjectMessageDTO;
import api.common.util.FileUtil;
import api.common.util.JsonUtil;
import api.common.util.LinuxUtil;
import api.common.util.TimeUtil;
import com.css.simulation.resource.scheduler.mapper.*;
import com.css.simulation.resource.scheduler.pojo.po.*;
import com.css.simulation.resource.scheduler.service.ManualProjectService;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.kafka.annotation.KafkaListener;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.stereotype.Component;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

@Component
@Slf4j
public class ManualProjectConsumer {

    @Autowired
    KafkaTemplate<String, String> kafkaTemplate;
    @Autowired
    StringRedisTemplate redisTemplate;
    @Autowired
    ManualProjectMapper manualProjectMapper;
    @Autowired
    AutoProjectMapper autoProjectMapper;
    @Autowired
    AutoSubProjectMapper autoSubProjectMapper;
    @Autowired
    TaskMapper taskMapper;
    @Autowired
    IndexMapper indexMapper;
    @Autowired
    IndexTemplateMapper indexTemplateMapper;
    @Autowired
    SceneMapper sceneMapper;
    @Autowired
    VehicleMapper vehicleMapper;
    @Autowired
    SensorCameraMapper sensorCameraMapper;
    @Autowired
    SensorOgtMapper sensorOgtMapper;
    @Autowired
    AlgorithmMapper algorithmMapper;
    @Autowired
    UserMapper userMapper;
    @Autowired
    ManualProjectService manualProjectService;
    //    @Autowired
//    ApiClient apiClient;
    @Value("${scheduler.manual-project.topic}")
    String manualProjectTopic;
    @Value("${scheduler.manual-project.result-path-minio}")
    String resultPathMinio;
    @Value("${scheduler.manual-project.job-template}")
    String jobTemplate;
    @Value("${scheduler.manual-project.job-yaml}")
    String jobYaml;


    /**
     * 任务运行前首先判断用户是否拥有可分配资源
     *
     * @param projectRecord 项目启动消息
     */
    @KafkaListener(groupId = "simulation-resource-scheduler", topics = "${scheduler.manual-project.topic}")
    @SneakyThrows
    public void cacheManualProject(ConsumerRecord<String, String> projectRecord) {
        log.info("------- ManualProjectConsumer--cacheManualProject 接收到项目开始消息为：" + projectRecord);
        String projectJson = projectRecord.value();
        //1 读取 kafka 的 project 信息
        ProjectMessageDTO projectMessageDTO = JsonUtil.jsonToBean(projectJson, ProjectMessageDTO.class);
        String projectId = projectMessageDTO.getProjectId();    // 项目 id
        String packageId = projectMessageDTO.getScenePackageId();   // 场景测试包 id
        int maxSimulationTime = projectMessageDTO.getMaxSimulationTime(); // 最大仿真时间，即生成视频的时间长度
        String vehicleConfigId = projectMessageDTO.getVehicleConfigId();// 模型配置 id
        String algorithmId = projectMessageDTO.getAlgorithmId();    // 算法 id
        //2 根据 projectId 获取创建用户 id
        String userId = manualProjectMapper.selectCreateUserById(projectId);
        //3 获取用户类型（管理员账户、管理员子账户、普通账户、普通子账户）（独占、共享）
        UserPO userPO = userMapper.selectById(userId);
        String roleCode = userPO.getRoleCode();
        String useType = userPO.getUseType();
        if (DictConstants.ROLE_CODE_SYSADMIN.equals(roleCode) || DictConstants.ROLE_CODE_ADMIN.equals(roleCode)) {  //3-1 管理员账户和管理员子账户直接执行
            parseManualProject(projectRecord);
        } else if (DictConstants.ROLE_CODE_UESR.equals(roleCode)) {
//            if (DictConstants.USE_TYPE_EXCLUSIVE.equals(useType)) {   //3-2 普通独占账户，根据自己的独占节点排队
//                // 获取独占数量
//                // 获取该用户正在运行的项目数量
//                // 获取
//            } else {
//
//            }
            parseManualProject(projectRecord);
        } else if (DictConstants.ROLE_CODE_SUBUESR.equals(roleCode)) {
            if (DictConstants.USE_TYPE_EXCLUSIVE.equals(useType)) {   //3-2 普通独占子账户，根据自己的独占节点排队

            } else {

            }
            parseManualProject(projectRecord);
        } else {
            parseManualProject(projectRecord);
        }

    }


    /**
     * 开始执行以及重新执行
     *
     * @param projectRecord 项目启动消息
     */
    @SneakyThrows
    public void parseManualProject(ConsumerRecord<String, String> projectRecord) {

        // -------------------------------- 0 准备 --------------------------------
        log.info("------- ManualProjectConsumer 接收到项目开始消息为：" + projectRecord);
        String projectJson = projectRecord.value();
        //1 读取 kafka 的 project 信息
        ProjectMessageDTO projectMessageDTO = JsonUtil.jsonToBean(projectJson, ProjectMessageDTO.class);
        String projectId = projectMessageDTO.getProjectId();    // 项目 id
        String packageId = projectMessageDTO.getScenePackageId();   // 场景测试包 id
        int maxSimulationTime = projectMessageDTO.getMaxSimulationTime(); // 最大仿真时间，即生成视频的时间长度
        String vehicleConfigId = projectMessageDTO.getVehicleConfigId();// 模型配置 id
        String algorithmId = projectMessageDTO.getAlgorithmId();    // 算法 id
        String userId = manualProjectMapper.selectCreateUserById(projectId);
        //2 执行前准备，删除改项目下所有任务，即重新执行改项目时需要新的测试包
        manualProjectService.prepare(manualProjectTopic, userId, projectId, projectJson);
        // -------------------------------- 1 查询场景 --------------------------------
        //1-1 根据场景测试包 packageId，拿到场景集合（不包括重复场景），重复场景会在发送消息时根据叶子指标发送多次。
        List<ScenePO> scenePOList = manualProjectService.handlePackage(manualProjectTopic, userId, projectId, packageId);
        Set<ScenePO> scenePOSet = new HashSet<>(scenePOList);
        // -------------------------------- 2 查询模型 --------------------------------
        //2-1 根据车辆配置id vehicleConfigId, 获取 模型信息和传感器信息
        VehiclePO vehiclePO = vehicleMapper.selectByVehicleConfigId(vehicleConfigId);   // 车辆
        List<CameraPO> cameraPOList = sensorCameraMapper.selectCameraByVehicleConfigId(vehicleConfigId);    // 摄像头
        List<OgtPO> ogtPOList = sensorOgtMapper.selectOgtByVehicleId(vehicleConfigId); // 完美传感器
        // -------------------------------- 3 发送任务消息 --------------------------------
        manualProjectService.sendTaskMessage(manualProjectTopic, userId, projectId, maxSimulationTime, scenePOSet, vehiclePO, cameraPOList, ogtPOList);
        // -------------------------------- 4 算法导入（一期按单机版做） --------------------------------
        String algorithmDockerImage = manualProjectService.handleAlgorithm(projectId, algorithmId);
        // -------------------------------- 5 创建 pod 开始执行 --------------------------------
        int completions = scenePOList.size();     // 结束标
        int parallelism = projectMessageDTO.getParallelism();    // 并行度
        log.info("------- ManualProjectConsumer 项目 " + projectId + " 的完成度为：" + completions);
        log.info("------- ManualProjectConsumer 项目 " + projectId + " 的并行度为：" + parallelism);
        String jobTemplateYamlPathSource = jobTemplate + "job-template.yaml";
        String jobTemplateYamlPathTarget = jobYaml + "project-" + projectId + ".yaml";
        String yamlSource = FileUtil.read(jobTemplateYamlPathSource);
        log.info("------- ManualProjectConsumer 模板文件为：" + yamlSource);
        String replace0 = yamlSource.replace("job-cloud-simulation", "project-" + projectId);
        String replace1 = replace0.replace("vtd-container", "vtd-" + projectId);
        String replace2 = replace1.replace("algorithm-container", "algorithm-" + projectId);
        String replace3 = replace2.replace("algorithm-image", algorithmDockerImage);
        String replace4 = replace3.replace("projectId", projectId);
        String replace5 = replace4.replace("completions-number", completions + "");
        String replace6 = replace5.replace("parallelism-number", parallelism + "");
        String replace7 = replace6.replace("apiVers1on", "apiVersion");
        String replace8 = replace7.replace("1atch/v1", "batch/v1");
        log.info("------- ManualProjectConsumer 开始执行 yaml 文件" + replace8);
        FileUtil.writeStringToLocalFile(replace8, jobTemplateYamlPathTarget);
        LinuxUtil.execute("kubectl apply -f " + jobTemplateYamlPathTarget);
    }

    @KafkaListener(groupId = "simulation-resource-scheduler", topics = "${scheduler.manual-project.stop-topic}")
    @SneakyThrows
    public void stopManualProject(ConsumerRecord<String, String> stopRecord) {
        log.info("ManualProjectConsumer--stopManualProject 接收到的项目终止消息为：" + stopRecord);
        //1 读取 kafka 的项目停止信息
        /*
            {
                "projectId": "sadfasdfs",	// 项目 id
            }
         */
        String json = stopRecord.value();
        ObjectMapper objectMapper = new ObjectMapper();
        JsonNode jsonNode = objectMapper.readTree(json);
        String projectId = jsonNode.path("projectId").asText();
        manualProjectMapper.updateProjectState(projectId, DictConstants.PROJECT_TERMINATED, TimeUtil.getNowForMysql());
        LinuxUtil.execute("kubectl delete job project-" + projectId);
        redisTemplate.delete(manualProjectTopic + ":" + projectId + ":check");
    }


}
