package com.css.simulation.resource.scheduler.service;

import api.common.pojo.common.ResponseBodyVO;
import api.common.util.FileUtil;
import com.css.simulation.resource.scheduler.mapper.AlgorithmMapper;
import com.css.simulation.resource.scheduler.util.MinioUtil;
import io.minio.MinioClient;
import lombok.SneakyThrows;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.io.InputStream;
import java.util.Set;

@Service
public class AlgorithmService {

    @Autowired
    AlgorithmMapper algorithmMapper;
    @Autowired
    MinioClient minioClient;
    @Value("${minio.bucket-name}")
    String bucketName;
    @Value("${scheduler.linux-temp-path}")
    String linuxTempPath;

    @SneakyThrows
    public ResponseBodyVO<String> check(String minioPath) {

        String[] split = minioPath.split("\\.");
        int length = split.length;
        String s = split[length - 1];

        //1 根据 minio 路径获取输入流
        InputStream inputStream = MinioUtil.downloadToStream(minioClient, bucketName, minioPath);
        //2 将输入流解压到临时目录
        String algorithmTarLinuxTempPath = linuxTempPath + minioPath;
        Set<String> pathList = FileUtil.decompress(inputStream, algorithmTarLinuxTempPath, "." + s);
        //3 获取文件列表中是否有 docker-entrypoint.sh
        boolean result = false;
        for (String path : pathList) {
            if (path.contains(".dockerenv")) {
                result = true;
                break;
            }
        }

        FileUtil.rm(algorithmTarLinuxTempPath);
        if (result) {
            return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS, "算法可用！", null);
        } else {
            return new ResponseBodyVO<>(ResponseBodyVO.Response.CLIENT_FAILURE, "算法不可用！", null);
        }

    }
}
