package com.css.simulation.resource.scheduler.util;

import io.kubernetes.client.openapi.ApiClient;
import io.kubernetes.client.openapi.ApiException;
import io.kubernetes.client.openapi.apis.BatchV1Api;
import io.kubernetes.client.openapi.apis.CoreV1Api;
import io.kubernetes.client.openapi.models.V1Namespace;
import io.kubernetes.client.openapi.models.V1ObjectMeta;
import io.kubernetes.client.openapi.models.V1PodList;

import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

public class KubernetesUtil {


    /**
     * 创建 namespace 命名空间
     *
     * @param apiClient     客户端
     * @param namespaceName 命名空间名称
     * @return 命名空间对象
     * @throws ApiException 异常
     */
    public static V1Namespace createNamespace(ApiClient apiClient, String namespaceName) throws ApiException {
        CoreV1Api coreV1Api = new CoreV1Api(apiClient);
        V1Namespace yaml = new V1Namespace();
        //1 apiVersion
        yaml.setApiVersion("v1");

        //2 kind
        yaml.setKind("Namespace");

        //3 metadata
        V1ObjectMeta metadata = new V1ObjectMeta();
        metadata.setName(namespaceName);
        metadata.setLabels(null);
        yaml.setMetadata(metadata);

        return coreV1Api.createNamespace(yaml, null, null, null, null);
    }

    public static List<String> getPod(ApiClient apiClient, String namespaceName) throws ApiException {

        CoreV1Api api = new CoreV1Api(apiClient);
        V1PodList list;
        if (namespaceName == null || "".equals(namespaceName)) {
            list = api.listNamespacedPod(
                    "default",
                    null,
                    null,
                    null,
                    null,
                    null,
                    null,
                    null,
                    null,
                    null,
                    null);
        } else if ("all".equals(namespaceName)) {
            list = api.listPodForAllNamespaces(
                    null,
                    null,
                    null,
                    null,
                    null,
                    null,
                    null,
                    null,
                    null,
                    null);
        } else {
            list = api.listNamespacedPod(
                    namespaceName,
                    null,
                    null,
                    null,
                    null,
                    null,
                    null,
                    null,
                    null,
                    null,
                    null);
        }
        return list.getItems().stream().map(pod -> Objects.requireNonNull(pod.getMetadata()).getName()).collect(Collectors.toList());
    }


    public static void deleteJob(ApiClient apiClient, String namespaceName, String jobName) throws ApiException {
        BatchV1Api batchV1Api = new BatchV1Api(apiClient);
        batchV1Api.deleteNamespacedJob(jobName, namespaceName, null, null, null, null, null, null);
    }
}
