package com.css.simulation.resource.algorithm.serviceImpl;
import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.param.MinioParameter;
import api.common.pojo.param.algorithm.AlgorithmParameter;
import api.common.pojo.param.system.DictParam;
import api.common.pojo.po.algorithm.AlgorithmPO;
import api.common.pojo.constants.DictConstants;
import api.common.util.*;
import api.common.pojo.vo.algorithm.AlgorithmVO;
import api.common.pojo.vo.algorithm.RunningProjectVO;
import com.css.simulation.resource.common.utils.AuthUtil;
import com.css.simulation.resource.common.utils.PageUtil;
import com.css.simulation.resource.algorithm.mapper.AlgorithmMapper;
import com.css.simulation.resource.algorithm.service.AlgorithmService;
import com.css.simulation.resource.common.utils.PoUtil;
import com.css.simulation.resource.feign.AlgoPlatformService;
import com.css.simulation.resource.feign.FileDownService;
import com.css.simulation.resource.feign.SchedulerService;
import com.css.simulation.resource.system.service.DictService;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.github.pagehelper.PageInfo;
import feign.Response;
import org.eclipse.jgit.lib.Ref;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.security.KeyManagementException;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class AlgorithmServiceImpl implements AlgorithmService {

    @Resource
    AlgoPlatformService algoPlatformService;

    @Resource
    SchedulerService schedulerService;

    @Resource
    FileDownService fileDownService;

    @Autowired
    private AlgorithmMapper algorithmMapper;

    @Autowired
    DictService dictService;

    @Override
    public ResponseBodyVO addOrUpdate(AlgorithmParameter param) {

        String currentUserId = AuthUtil.getCurrentUserId();
        param.setCreateUserId(currentUserId);
        List<AlgorithmPO> algorithmPOS = algorithmMapper.selectAlgorithmName(param);
        if(algorithmPOS != null && algorithmPOS.size() > 0){
            return new ResponseBodyVO(ResponseBodyVO.Response.SERVER_FAILURE,"该算法名称已存在！");
        }else {
            String uploadMode = param.getUploadMode();
            if(DictConstants.FILE.equals(uploadMode)){
                String minioPath = param.getMinioPath();
                ResponseBodyVO<String> checkRes = schedulerService.check(minioPath);
                if(checkRes.isStatus()){
                    return doAddOrUpdate(param);
                }else {
                    MinioParameter minioParameter = new MinioParameter();
                    minioParameter.setObjectName(minioPath);
                    Response remove =fileDownService.remove(minioParameter);
                    if(remove.status() == 200){
                        return new ResponseBodyVO(ResponseBodyVO.Response.SERVER_FAILURE,"该算法经校验不可用，无法保存，算法文件已删除！");
                    }else {
                        return new ResponseBodyVO(ResponseBodyVO.Response.SERVER_FAILURE,"该算法经校验不可用，无法保存，算法文件删除失败！");
                    }
                }
            }else {
                 return doAddOrUpdate(param);
            }
        }
    }

    private ResponseBodyVO doAddOrUpdate(AlgorithmParameter param) {
        if(isEmpty(param.getId())){
            //添加
            String algorithmId = StringUtil.getRandomUUID();
            param.setId(algorithmId);
            String algorithmCode = StringUtil.getRandomCode();
            param.setAlgorithmCode(algorithmCode);
            AlgorithmPO po = setPo(param, false);
            int add = algorithmMapper.add(po);
            if(add > 0){
                LogUtil.insert();
                return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS);
            }else {
                return new ResponseBodyVO(ResponseBodyVO.Response.SERVER_FAILURE,"添加失败");
            }
        }else {
            //编辑
            AlgorithmPO po = setPo(param, true);
            int add = algorithmMapper.update(po);
            if (add > 0) {
                LogUtil.update();
                return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS);
            }else {
                return new ResponseBodyVO(ResponseBodyVO.Response.SERVER_FAILURE, "编辑失败");
            }
        }

    }

    @Override
    public ResponseBodyVO selectAlgorithmList(AlgorithmParameter param){
        param.setIsDeleted("0");
        param.setCreateUserId(AuthUtil.getCurrentUserId());
        PageUtil.setPageInfo(param);
        List<AlgorithmVO> vos = algorithmMapper.selectAlgorithmList(param);
        for (AlgorithmVO vo:vos){
            vo.setValidationStatus(getDictName(DictConstants.VALIDATION_STATUS, vo.getValidationStatus()));
        }
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS,new PageInfo<>(vos));
    }

    @Override
    public ResponseBodyVO selectAlgoPlatformList(AlgorithmParameter param){
        //获取参数
        String algorithmId = param.getAlgorithmCode();
        String algorithmName = param.getAlgorithmName();
        String description = param.getDescription();
        Integer page = param.getPageNum();
        Integer size = param.getPageSize();
        String sort = "algorithmId-desc";
        String urlParam = "";
        if (StringUtil.isNotEmpty(algorithmId)){
            urlParam = urlParam + "&algorithmId=" + algorithmId;
        }
        if (StringUtil.isNotEmpty(algorithmName)){
            urlParam = urlParam + "&algorithmName=" + algorithmName;
        }
        if (StringUtil.isNotEmpty(description)){
            urlParam = urlParam + "&description=" + description;
        }
        if (StringUtil.isNotEmpty(page)){
            urlParam = urlParam + "&page=" + page;
        }
        if (StringUtil.isNotEmpty(size)){
            urlParam = urlParam + "&size=" + size;
        }
        urlParam = urlParam + "&sort=" + sort;

        ResponseBodyVO algorithmList = algoPlatformService.getAlgorithmList(urlParam);

        //解析数据
        Map jsonMap = JsonUtil.jsonToMap((String) algorithmList.getInfo());
        Map<String, Object> dataMap = (Map<String, Object>) jsonMap.get("data");
        List<Map<String, String>> contentList = (List<Map<String, String>>) dataMap.get("content");
        Integer totalElements = (Integer) dataMap.get("totalElements");
        List<AlgorithmVO> vos = new ArrayList<>();
        if(totalElements > 0){
            for (Map<String, String> content: contentList) {
                AlgorithmVO vo = new AlgorithmVO();
                vo.setId(content.get("id"));
                vo.setAlgorithmCode(content.get("algorithmId"));
                vo.setAlgorithmName(content.get("algorithmName"));
                vo.setDescription(content.get("description"));
                vos.add(vo);
            }
        }
        PageInfo<AlgorithmVO> objectPageInfo = new PageInfo<>(vos);
        objectPageInfo.setTotal(totalElements);

        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS,objectPageInfo);
    }


    @Override
    public ResponseBodyVO selectSharedAlgorithmList(AlgorithmParameter param) {
        param.setShare("1");
        PageUtil.setPageInfo(param);
        List<AlgorithmVO> vos = algorithmMapper.selectSharedAlgorithmList(param);
        for (AlgorithmVO vo:vos){
            vo.setValidationStatus(getDictName(DictConstants.VALIDATION_STATUS, vo.getValidationStatus()));
        }
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS,new PageInfo<>(vos));
    }

    @Override
    public ResponseBodyVO shareAlgorithm(AlgorithmParameter param) {
        if(isEmpty(param.getId())){
            return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE);
        }else {
            String algorithmId = param.getId();
            AlgorithmPO po = algorithmMapper.selectDetailsById(algorithmId);
            List<AlgorithmPO> algorithmPOS = algorithmMapper.selectSharedAlgorithmName(po.getAlgorithmName());
            if(algorithmPOS != null && algorithmPOS.size() > 0){
                return new ResponseBodyVO(ResponseBodyVO.Response.SERVER_FAILURE,"该算法名称已存在, 无法分享！");
            }else {
                po.setShare("1");
                po.setId(StringUtil.getRandomUUID());
                po.setAlgorithmCode(StringUtil.getRandomCode());
                int add = algorithmMapper.add(po);
                if(add > 0){
                    LogUtil.share();
                    return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS,"分享成功");
                }
                return new ResponseBodyVO(ResponseBodyVO.Response.SERVER_FAILURE,"分享失败");

            }
        }
    }

    @Override
    public ResponseBodyVO testConnection(AlgorithmParameter param) {
        try{
            Map<String, Ref> asMap = JgitUtil.testConnection(param.getGitUrl(), param.getGitUserName(), param.getGitPassword());
        } catch (Exception e){
            return new ResponseBodyVO(ResponseBodyVO.Response.SERVER_FAILURE,"连接失败！");
        }
        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS,"连接成功");
    }

    @Override
    public String getGitVersion(String algorithmId)  {
        AlgorithmPO po = algorithmMapper.selectDetailsById(algorithmId);
        String gitUrl = po.getGitUrl();
        if(StringUtil.isEmpty(gitUrl)){
            return "";
        }
        //拼接get请求地址
        String prefix = "https://api.github.com/repos/";
        String suffix = "/commits?page=1&per_page=1";
        String gitInfo = gitUrl.substring(19, gitUrl.length()-4);
        String requestUrl = prefix + gitInfo + suffix;
        try {
            String result = HttpUtil.get(HttpUtil.getHttpClient(), HttpUtil.getRequestConfig(), requestUrl);
            List<HashMap> hashMaps = JsonUtil.jsonToList(result, HashMap.class);
            if(hashMaps.size() > 0){
                HashMap hashMap = hashMaps.get(0);
                String version = hashMap.get("sha").toString();
                return version;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return StringUtil.getRandomCode();
    }


    @Override
    public ResponseBodyVO deleteByid(AlgorithmParameter param) {
        if(isEmpty(param.getId())){
            return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE);
        }else {
            String algorithmId = param.getId();
            List<RunningProjectVO> runningProjectVos = algorithmMapper.selectRunningProject(algorithmId);
            if(runningProjectVos != null && runningProjectVos.size() > 0){
                StringBuffer stringBuffer = new StringBuffer("");
                for (RunningProjectVO vo:runningProjectVos){
                    String projectId = vo.getProjectId();
                    stringBuffer.append(projectId+",");
                }
                String substring = stringBuffer.substring(0, stringBuffer.lastIndexOf(","));
                return new ResponseBodyVO(ResponseBodyVO.Response.SERVER_FAILURE,"已被工作ID："+ substring +" 应用，无法删除！");
            }else {
                int i = algorithmMapper.deleteByid(param);
                if(i > 0){
                    LogUtil.delete();
                    return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS);
                }
                return new ResponseBodyVO(ResponseBodyVO.Response.SERVER_FAILURE,"删除失败");
            }
        }

    }

    @Override
    public ResponseBodyVO selectDetailsById(String algorithmId) {
        if(isEmpty(algorithmId)){
            return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE);
        }else {
            AlgorithmPO po = algorithmMapper.selectDetailsById(algorithmId);
            po.setValidationStatus(getDictName(DictConstants.VALIDATION_STATUS, po.getValidationStatus()));
            return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS,po);
        }

    }


    private boolean isEmpty(String value){
        if(value == null){
            return true;
        }
        value = value.trim();
        if(value.length() == 0){
            return true;
        }
        return false;
    }


    private AlgorithmPO setPo(AlgorithmParameter param,  Boolean isEdit) {

        AlgorithmPO po = new AlgorithmPO();
        //设置po信息
        if(DictConstants.GIT.equals(param.getUploadMode())){ //使用仓库地址上传
            String gitUrl = param.getGitUrl();
            String gitUserName = param.getGitUserName();
            String gitPassword = param.getGitPassword();
            po.setGitUrl(gitUrl);
            po.setGitUserName(gitUserName);
            po.setGitPassword(gitPassword);
        }else {
            String minioPath = param.getMinioPath();
            String[] splits = minioPath.split("/");
            String fileName = splits[splits.length-1];
            po.setMinioPath(param.getMinioPath());
            po.setFileName(fileName);
        }
        po.setAlgorithmCode(param.getAlgorithmCode());
        po.setAlgorithmName(param.getAlgorithmName());
        po.setDescription(param.getDescription());
        po.setUploadMode(param.getUploadMode());
        po.setValidationStatus(DictConstants.SUCCESS);
        po.setShare(DictConstants.NO);
        po.setId(param.getId());

        if(isEdit){
            PoUtil.initUpdatePo(po);
        }else {
            PoUtil.initAddPo(po);
        }
        return po;

    }

    private String getDictName(String type, String code) {
        DictParam dictParam = new DictParam();
        dictParam.setDictTypes(type);
        Map<String, Map<String, String>> dictMapsByTypes = dictService.getDictMapsByTypes(dictParam);
        Map<String, String> stringStringMap = dictMapsByTypes.get(type);
        if(stringStringMap != null && stringStringMap.size() > 0){
            return stringStringMap.get(code);
        }
        return "";
    }

    @Override
    public Map selectDetailsBySy() {
        AlgorithmParameter param=new AlgorithmParameter();
        param.setUploadMode("1");
        param.setShare("0");
        param.setCreateUserId(AuthUtil.getCurrentUserId());
        int fileNum= algorithmMapper.selectDetailsBySy(param);
        param.setUploadMode("2");
        int pathNum= algorithmMapper.selectDetailsBySy(param);
        Map map=new HashMap();
        map.put("fileNum",fileNum);
        map.put("pathNum",pathNum);
        return map;
    }

}
