package com.css.simulation.resource.project.ctrl;

import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.param.project.DictParam;
import api.common.pojo.param.project.SimulationManualProjectParam;
import com.css.simulation.resource.project.service.SimulationProjectService;
import com.css.simulation.resource.system.service.ClusterService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

/**
 * 工作台模块--项目运行
 */
@Controller
@RequestMapping("/simulationProject")
public class SimulationProjectCtrl {

    @Autowired
    private SimulationProjectService service;

    @Autowired
    private ClusterService clusterService;


    /**
     * 创建/修改工作
     * @param param
     * @return
     */
    @RequestMapping("addOrUpdateProject")
    @ResponseBody
    public ResponseBodyVO addOrUpdateProject(@RequestBody SimulationManualProjectParam param){
        return service.addOrUpdateProject(param);
    }

    /**
     * 查询项目列表
     * @param param
     * @return
     */
    @RequestMapping("selectProject")
    @ResponseBody
    public ResponseBodyVO selectProject(@RequestBody SimulationManualProjectParam param){
        return service.selectProject(param);
    }

    /**
     * 根据id查询
     * @return
     */
    @RequestMapping("selectProjectById")
    @ResponseBody
    public ResponseBodyVO selectProjectById(@RequestBody SimulationManualProjectParam param){
        return service.selectProjectById(param);
    }

    /**
     * 删除工作（支持批量删除）
     * @return
     */
    @RequestMapping("deleteProjectByids")
    @ResponseBody
    public ResponseBodyVO deleteProjectByids(@RequestBody SimulationManualProjectParam param){
        return service.deleteProjectByids(param);
    }

    /**
     * 修改工作运行状态
     * @param param
     * @return
     */
    @RequestMapping("updateProjectNowRunState")
    @ResponseBody
    public ResponseBodyVO updateProjectNowRunState(@RequestBody SimulationManualProjectParam param){
        return service.updateProjectNowRunState(param);
    }

    /**
     * 获取工作详情
     * @param param
     * @return
     */
    @RequestMapping("selectProjectDetailsById")
    @ResponseBody
    public ResponseBodyVO selectProjectDetailsById(@RequestBody SimulationManualProjectParam param){
        return service.selectProjectDetailsById(param);
    }

    /**
     * 获取测试报告详情
     * @param param
     * @return
     */
    @RequestMapping("selectProjectReportById")
    @ResponseBody
    public  ResponseBodyVO selectProjectReportById(@RequestBody SimulationManualProjectParam param){
        return service.selectProjectReportById(param);
    }

    /**
     * 获取任务详情信息
     * @param param
     * @return
     */
    @RequestMapping("selectProjectTaskById")
    @ResponseBody
    public ResponseBodyVO selectProjectTaskById(@RequestBody SimulationManualProjectParam param){
        return service.selectProjectTaskById(param);
    }

    /**
     * 获取添加工作时需要的下拉选项
     * @return
     */
    @RequestMapping("selectDropDownByType")
    @ResponseBody
    public ResponseBodyVO selectDropDownByType(@RequestBody SimulationManualProjectParam param){
        return service.selectDropDownByType(param);
    }


    /**
     * 获取人员可用最大并行度
     * @return
     */
    @RequestMapping("selectMaxParallelism")
    @ResponseBody
    public ResponseBodyVO selectMaxParallelism(){

        Integer licenseNum = clusterService.getLicenseNum();

        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS,null,licenseNum);
//        return service.selectMaxParallelism();
    }

    /**
     * 根据字典类型和code获取name（测试方法）
     * @param param
     * @return
     */
    @RequestMapping("getDictName")
    @ResponseBody
    public ResponseBodyVO getDictName(@RequestBody DictParam param) {
        String dictName = service.getDictName(param.getType(), param.getCode());
        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS,null,dictName);

    }


    /**
     * 解析车辆坐标文件
     * @return
     */
    @RequestMapping("analysisVehicleCoord")
    @ResponseBody
    public ResponseBodyVO analysisVehicleCoord() throws Exception {
        return service.analysisVehicleCoord();
    }


    /**
     * 查询工作任务列表
     * @param param
     * @return
     */
    @RequestMapping("selectProjectTaskList")
    @ResponseBody
    public ResponseBodyVO selectProjectTaskList(@RequestBody SimulationManualProjectParam param){
        return service.selectProjectTaskList(param);
    }


    /**
     * 导出测试报告
     * @return
     */
    @RequestMapping("exportProjectReportById")
    @ResponseBody
    public void exportProjectReportById(@RequestBody SimulationManualProjectParam param) {
        service.exportProjectReport(param);
    }

    /**
     * 生成保存评测等级（任务结果返回时调用）
     * @return
     */
    @RequestMapping("saveEvaluationLevel")
    @ResponseBody
    public ResponseBodyVO saveEvaluationLevel(@RequestBody SimulationManualProjectParam param){
        return service.saveEvaluationLevel(param);
    }

    /**
     *保存仿真结果到数据库（任务结果返回时调用）
     * @param param
     * @return
     */
    @RequestMapping("saveTaskResult")
    @ResponseBody
    public ResponseBodyVO saveTaskResult(@RequestBody SimulationManualProjectParam param){
        return service.saveTaskResult(param);
    }

    /**
     * 导出工作任务文件包
     * @return
     */
    @RequestMapping("exportProjectTaskFileById")
    @ResponseBody
    public void exportProjectTaskFileById(@RequestBody SimulationManualProjectParam param){
        service.exportProjectTaskFileById(param);
    }

    /**
     * 同时导出工作报告和任务包
     * @param param
     */
    @RequestMapping("exportProjectReportAndTaskFileById")
    @ResponseBody
    public void exportProjectReportAndTaskFileById(@RequestBody SimulationManualProjectParam param){
        service.exportProjectReportAndTaskFileById(param);
    }


    /**
     * 添加编辑自动项目
     * @param param
     * @return
     */
    @RequestMapping("addOrUpdateAutomaticProject")
    @ResponseBody
    public ResponseBodyVO addOrUpdateAutomaticProject(@RequestBody SimulationManualProjectParam param){
        return service.addOrUpdateAutomaticProject(param);
    }


    /**
     * 删除自动运行工作（支持批量删除）
     * @return
     */
    @RequestMapping("deleteAutomaticProjectByids")
    @ResponseBody
    public ResponseBodyVO deleteAutomaticProjectByids(@RequestBody SimulationManualProjectParam param){
        return service.deleteAutomaticProjectByids(param);
    }

    /**
     * 修改自动运行状态
     */
    @RequestMapping("updateAutomaticRunState")
    @ResponseBody
    public  ResponseBodyVO updateAutomaticRunState(@RequestBody SimulationManualProjectParam param){
        return service.updateAutomaticRunState(param);
    };

    /**
     * 查询自动运行项目列表
     */
    @RequestMapping("selectAutomaticProject")
    @ResponseBody
    public ResponseBodyVO selectAutomaticProject(@RequestBody SimulationManualProjectParam param){
        return service.selectAutomaticProject(param);
    }

    /**
     * 手动运行自动项目
     */
    @RequestMapping("createAutomaticSubProject")
    @ResponseBody
    public ResponseBodyVO createAutomaticSubProject(@RequestBody SimulationManualProjectParam param){
        return service.createAutomaticSubProject(param);
    }

    /**
     * 删除自动运行子项目（支持批量删除）
     */
    @RequestMapping("deleteAutomaticSubProjectByIds")
    @ResponseBody
    public ResponseBodyVO deleteAutomaticSubProjectByIds(@RequestBody SimulationManualProjectParam param){

        return service.deleteAutomaticSubProjectByIds(param);
    }

    /**
     * 查询自动运行子工作信息
     * @return
     */
    @RequestMapping("selectSubProjectInfo")
    @ResponseBody
    public ResponseBodyVO selectSubProjectInfo(@RequestBody SimulationManualProjectParam param){
        return service.selectSubProjectInfo(param);
    }


    /**
     * 查询自动运行子工作列表
     * @return
     */
    @RequestMapping("selectSubProjectList")
    @ResponseBody
    public ResponseBodyVO selectSubProjectList(@RequestBody SimulationManualProjectParam param){
        return service.selectSubProjectList(param);
    }

    /**
     * 根据id查询自动运行项目信息
     */
    @RequestMapping("selectAutomaticProjectById")
    @ResponseBody
    public ResponseBodyVO selectAutomaticProjectById(@RequestBody SimulationManualProjectParam param){
        return service.selectAutomaticProjectById(param);
    }

    /**
     * 修改自动运行子工作运行状态
     * @param param
     * @return
     */
    @RequestMapping("updateAutoProjectNowRunState")
    @ResponseBody
    public ResponseBodyVO updateAutoProjectNowRunState(@RequestBody SimulationManualProjectParam param){
        return service.updateAutoProjectNowRunState(param);
    }


}
