package com.css.simulation.resource.scene.ctrl;

import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.constants.DictConstants;
import api.common.pojo.param.MinioParameter;
import api.common.pojo.param.RedisParameter;
import api.common.util.ObjectUtil;
import api.common.util.TimeUtil;
import com.css.simulation.resource.feign.FileDownService;
import com.css.simulation.resource.feign.RedisService;
import feign.Response;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

//文件上传下载
@Slf4j
@RestController
@RequestMapping("/file")
public class FileController {

    @Resource
    private FileDownService fileDownService;

    @Resource
    private RedisService redisService;

    @PostMapping(value = "/uploadWj", consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
    public ResponseBodyVO<Map> uploadWj(@RequestParam("file") MultipartFile multipartFile, HttpServletRequest request) {
        //获取文件类型
        String type = request.getParameter("type");
        String objectPath = request.getParameter("objectPath");
        if (multipartFile != null) {
            String fileName = "";
            Integer nowTime = TimeUtil.getRq(new Date(), 0);
            if (type.equals(DictConstants.SCENE_NATURAL)) {
                fileName = "自然驾驶场景/" + nowTime + "/" + objectPath + "/" + multipartFile.getOriginalFilename();
            } else if (type.equals(DictConstants.SCENE_STANDARD)) {
                fileName = "标准法规场景/" + nowTime + "/" + objectPath + "/" + multipartFile.getOriginalFilename();
            } else if (type.equals(DictConstants.SCENE_ACCIDENT)) {
                fileName = "交通事故场景/" + nowTime + "/" + objectPath + "/" + multipartFile.getOriginalFilename();
            } else if (type.equals(DictConstants.SCENE_GENERAL)) {
                fileName = "泛化场景/" + nowTime + "/" + objectPath + "/" + multipartFile.getOriginalFilename();
            } else {
                fileName = multipartFile.getOriginalFilename();
            }
            ResponseBodyVO<String> respon;
            respon = fileDownService.upload(multipartFile, fileName);
            String videoPreview = respon.getMessage();
            Map map = new HashMap();
           // map.put("videoPreview", videoPreview);
            map.put("fileName", fileName);

            return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS, map);
        }
        return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "文件流file为空，请检查！");
    }

    @PostMapping(value = "/download")
    public void download(
            HttpServletResponse response, @RequestBody @Validated MinioParameter parms
    ) throws IOException {
        Response download = fileDownService.download(parms);
        Response.Body body = download.body();
        InputStream inputStream = body.asInputStream();
        downloadForHttp(parms.getObjectName(), inputStream, response, 1024);
    }

    @PostMapping(value = "/getProgress")
    public ResponseBodyVO getProgress(@RequestBody Map<String,String> paramMap){
        String objectPath = paramMap.get("objectPath");
        RedisParameter redisParameter = new RedisParameter();
        redisParameter.setKey(DictConstants.ALGORITHM_KEY + objectPath);
        ResponseBodyVO resp = redisService.getProgress(redisParameter);
        if(ObjectUtil.isNull(resp.getInfo())){
            resp.setInfo("0.00");
        }
        return resp;
    }



    public void downloadForHttp(String fileName, InputStream in, HttpServletResponse response, int bufferSize) throws IOException {
        int idx = fileName.lastIndexOf("/");
        fileName = fileName.substring(idx + 1, fileName.length());

        log.info("下载----" + fileName);
        response.setContentType("application/octet-stream;charset=utf-8");
        response.setHeader("Content-Disposition", "attachment;filename=\"" + fileName + "\"");
        copyBytes(in, response.getOutputStream(), bufferSize);
    }

    public static void copyBytes(InputStream in, OutputStream out, int bufferSize) throws IOException {
        byte[] buffer = new byte[bufferSize];
        for (int bytesRead = in.read(buffer); bytesRead >= 0; bytesRead = in.read(buffer)) {
            out.write(buffer, 0, bytesRead);
        }
    }

//从minio获取文件列表
    @PostMapping(value = "/queryList")
    public List<String> queryList(@RequestBody @Validated MinioParameter parms
    ) throws IOException {
        List<String> list = fileDownService.list(parms).getInfo();
        return list;
    }

    @PostMapping(value = "/queryList1")
    public List<String> queryList1(@RequestBody @Validated MinioParameter parms
    ) throws IOException {
        List<String> list = fileDownService.listDeepOne(parms).getInfo();
        return list;
    }


}