package com.css.simulation.resource.scene.ctrl;

import api.common.pojo.common.PageVO;
import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.vo.home.AccessVO;
import api.common.pojo.vo.home.HardwareVO;
import api.common.pojo.vo.home.ServiceVO;
import api.common.pojo.vo.home.SystemServerVO;
import com.css.simulation.resource.algorithm.service.AlgorithmService;
import com.css.simulation.resource.project.service.SimulationProjectService;
import com.css.simulation.resource.scene.service.HomePageService;
import com.css.simulation.resource.scene.service.SceneNaturalService;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

//首页系统概览
@Slf4j
@RestController
@RequestMapping("/homePage")
public class HomePageController {
    @Autowired
    SceneNaturalService sceneNaturalService;
    @Autowired
    AlgorithmService algorithmService;
    @Autowired
    SimulationProjectService simulationProjectService;
    @Autowired
    com.css.simulation.resource.model.service.ConfigService ConfigService;
    @Autowired
    HomePageService homePageService;

    //首页概况汇总方法
    @PostMapping("/queryAllNum")
    @ResponseBody
    public ResponseBodyVO<Map<String,Integer>> queryAllNum() {

        Map<String,Integer> map = algorithmService.selectDetailsBySy();
        map.put("ConfigTotal", ConfigService.getConfigTotal());
        map.put("SceneNum", sceneNaturalService.querySceneNumBySy());
        map.put("maxConcurrency", 1);
        map.put("currentConcurrency", 1);
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS, map);
    }


    //首页查询场景数量
    @PostMapping("/querySceneNumBySy")
    @ResponseBody
    public ResponseBodyVO<Integer> querySceneNumBySy() {
        Integer SceneNum = sceneNaturalService.querySceneNumBySy();
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS, SceneNum);
    }

    //首页车辆配置数量
    @PostMapping("/queryCarDisposeNumBySy")
    @ResponseBody
    public ResponseBodyVO<Integer> queryCarDisposeNumBySy() {
        Integer ConfigTotal = ConfigService.getConfigTotal();
        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS, ConfigTotal);
    }

    /**
     * 首页文件数量
     *
     * @param
     * @return
     */
    @RequestMapping("selectDetailsBySy")
    @ResponseBody
    public ResponseBodyVO selectDetailsBySy() {

        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS, algorithmService.selectDetailsBySy());
    }

    /**
     * 近一周运行运行项目数量
     *
     * @param
     * @return
     */
    @RequestMapping("selectRunProjectBySy")
    @ResponseBody
    public ResponseBodyVO selectRunProjectBySy() {
        return simulationProjectService.selectRunProjectBySy();
    }

    /**
     * 近一周运行任务数量
     *
     * @param
     * @return
     */
    @RequestMapping("selectRunTaskBySy")
    @ResponseBody
    public ResponseBodyVO selectRunTaskBySy() {
        return simulationProjectService.selectRunTaskBySy();
    }

    /**
     * 任务运行状态统计-饼图
     *
     * @param
     * @return
     */
    @RequestMapping("selectRunTaskByState")
    @ResponseBody
    public ResponseBodyVO selectRunTaskByState() {
        return simulationProjectService.selectRunTaskByState();
    }

    /**
     * 项目运行状态统计-饼图
     */
    @RequestMapping("selectRunProjectByState")
    @ResponseBody
    public ResponseBodyVO selectRunProjectByState() {
        return simulationProjectService.selectRunProjectByState();
    }

    /**
     * 评测等级分布-饼图
     */
    @RequestMapping("selectEvaluationLevel")
    @ResponseBody
    public ResponseBodyVO selectEvaluationLevel() {
        return simulationProjectService.selectEvaluationLevel();
    }


    /**
     * 硬件监控
     */
    @RequestMapping("selectHardware")
    @ResponseBody
    public ResponseBodyVO<HardwareVO> selectHardware() {
        return homePageService.selectHardware();
    }

    /**
     * 服务监控
     */
    @RequestMapping("selectService")
    @ResponseBody
    public ResponseBodyVO<ServiceVO> selectService() {
        return homePageService.selectService();
    }

    /**
     * 日访问人数
     */
    @RequestMapping("selectAccess")
    @ResponseBody
    public ResponseBodyVO<List<AccessVO>> selectAccess() {
        return homePageService.selectAccess();
    }


    /**
     * 服务器监控
     */
    @RequestMapping("selectServer")
    @ResponseBody
    public ResponseBodyVO<PageInfo<SystemServerVO>> selectServer(PageVO pageVO) {
        return homePageService.selectServer(pageVO);
    }
}