package com.css.simulation.resource.scene.ctrl;

import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.param.scene.SceneGeneralTemplateParam;
import api.common.pojo.po.scene.SceneGeneralDataPO;
import api.common.pojo.po.scene.SceneGeneralExamplePO;
import api.common.pojo.po.scene.SceneGeneralTemplatePO;
import api.common.pojo.vo.scene.SceneGeneralTemplateVO;
import api.common.util.HttpUtil;
import api.common.util.JsonUtil;
import api.common.util.ObjectUtil;
import api.common.util.TimeUtil;
import com.css.simulation.resource.common.utils.PageUtil;
import com.css.simulation.resource.feign.FileDownService;
import com.css.simulation.resource.scene.service.SceneGeneralExampleService;
import com.css.simulation.resource.scene.service.SceneGeneralTemplateService;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageInfo;
import org.apache.http.client.config.RequestConfig;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import javax.annotation.Resource;
import java.io.File;
import java.io.IOException;
import java.lang.reflect.Field;
import java.security.KeyManagementException;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

//泛化场景
@RestController
@RequestMapping("/SceneGeneralTemplate")
public class SceneGeneralTemplateController {

    @Resource
    SceneGeneralTemplateService sceneGeneralTemplateService;
    @Resource
    SceneGeneralExampleService exampleService;
    @Resource
    private FileDownService fileDownService;

    //查询列表
    @PostMapping("/querySceneGeneralTemplateList")
    @ResponseBody
    public ResponseBodyVO<List<SceneGeneralTemplatePO>> querySceneGeneralTemplateList(@RequestBody SceneGeneralTemplateParam po) {
        PageUtil.setPageInfo(po);
        List<SceneGeneralTemplatePO> list = sceneGeneralTemplateService.querySceneGeneralTemplateList(po);
        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS, new PageInfo<>(list));
    }

    //查模板详情
    @PostMapping("/querySceneGeneralTemplateById")
    @ResponseBody
    public ResponseBodyVO<SceneGeneralTemplateVO> querySceneGeneralTemplateById(@RequestBody SceneGeneralTemplateParam param) {
        if (param != null && ObjectUtil.isNotNull(param.getId())) {
            SceneGeneralTemplateVO po = sceneGeneralTemplateService.querySceneGeneralTemplateById(param.getId());
            return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS, po);
        }
        return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "参数id不能为空，请检查");

    }

    //新增泛化模板
    @PostMapping("/saveSceneGeneralTemplate")
    @ResponseBody
    public ResponseBodyVO<String> saveSceneGeneralTemplate(@RequestParam("file") MultipartFile multipartFile) {
        File file = null;
        String originalFilename = multipartFile.getOriginalFilename();
        if (originalFilename.indexOf(".xls") == -1 && originalFilename.indexOf(".xlsx") == -1) {
            return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "文件格式错误，请检查模板.");

        }
        //版本号
        String version = TimeUtil.getToStringDate(new Date(), 5);
        try {
            ResponseBodyVO<String> respon;
           // Integer nowTime = TimeUtil.getRq(new Date(), 0);
            String fileName = "泛化场景/" + version + "/" + originalFilename;
            respon = fileDownService.upload(multipartFile, fileName);

            String[] filename = originalFilename.split("\\.");
            file = File.createTempFile(filename[0], filename[1]);
            multipartFile.transferTo(file);
            file.deleteOnExit();
        } catch (IOException e) {
            e.printStackTrace();
            return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "模板解析失败，请检查模板.");

        }
        return sceneGeneralTemplateService.saveSceneGeneralTemplate(file, version);

    }

    //删除泛化模板
    @PostMapping("/deleteSceneGeneralTemplateById")
    @ResponseBody
    public ResponseBodyVO<String> deleteSceneGeneralTemplateById(@RequestBody SceneGeneralTemplatePO po) {
        return sceneGeneralTemplateService.deleteSceneGeneralTemplateById(po);

    }

    //查看泛化实例详情页面

    @PostMapping("/queryGeneralTemplateByFh")
    @ResponseBody
    public ResponseBodyVO queryGeneralTemplateByFh(@RequestBody SceneGeneralExamplePO param) {
        if (param != null && ObjectUtil.isNotNull(param.getId())) {
            return exampleService.querySceneGeneralExampleById(param.getId());
        }
        return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "参数id不能为空，请检查");
    }


    //泛化实例保存及调用外部接口
    @PostMapping("/saveSceneGeneralExample")
    @ResponseBody
    public ResponseBodyVO saveSceneGeneralExample(@RequestBody SceneGeneralTemplateVO vo) {
        if (ObjectUtil.isNotNull(vo)) {
            return exampleService.saveSceneGeneralExample(vo);
        }
        return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "参数不能为空，请检查");
    }

    //查询模块名称
    @PostMapping("/queryType")
    @ResponseBody
    public ResponseBodyVO queryType() {
        return exampleService.queryType();
    }


    //测试
    @PostMapping("/test1")
    @ResponseBody
    public ResponseBodyVO test1(@RequestBody SceneGeneralTemplatePO po) throws IllegalAccessException, IOException, NoSuchAlgorithmException, KeyStoreException, KeyManagementException {
        Map map = beanToMap(po);
        RequestConfig requestConfig = RequestConfig.custom()
                .setSocketTimeout(6 * 10 * 1000)
                .setConnectTimeout(6 * 10 * 1000)
                .setConnectionRequestTimeout(6 * 10 * 1000)
                .setRedirectsEnabled(false)
                .setExpectContinueEnabled(false)
                .build();

        String post = HttpUtil.post(HttpUtil.getHttpClient(), requestConfig, "http://47.94.105.148:5000/test_1.0", null, map);
        JsonNode params = JsonUtil.readTree(post).get("params");
        // 实例化 ObjectMapper 对象
        ObjectMapper objectMapper = new ObjectMapper();
        String newjson = objectMapper.writeValueAsString(params);
        List<SceneGeneralDataPO> list = JsonUtil.jsonToList(newjson, SceneGeneralDataPO.class);
        return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "参数不能为空，请检查");
    }

    /**
     * 对象转Map
     *
     * @param object
     * @return
     * @throws IllegalAccessException
     */
    public static Map beanToMap(Object object) throws IllegalAccessException {
        Map<String, Object> map = new HashMap<String, Object>();
        Field[] fields = object.getClass().getDeclaredFields();
        for (Field field : fields) {
            field.setAccessible(true);
            map.put(field.getName(), field.get(object));
        }
        return map;
    }

}