package com.css.simulation.resource.scene.ctrl;

import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.param.scene.ScoringRulesParam;
import api.common.pojo.po.scene.ScoringRulesPO;
import api.common.pojo.vo.scene.ScoringRulesVO;
import api.common.util.ObjectUtil;
import com.css.simulation.resource.common.utils.AuthUtil;
import com.css.simulation.resource.common.utils.PageUtil;
import com.css.simulation.resource.scene.service.ScoringRulesService;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.BeanUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

//打分规则
@RestController
@RequestMapping("/ScoringRules")
public class ScoringRulesController {

    @Resource
    ScoringRulesService scoringRulesService;

    //查询列表
    @PostMapping("/queryScoringRulesList")
    @ResponseBody
    public ResponseBodyVO<List<ScoringRulesVO>> queryScoringRulesList(@RequestBody ScoringRulesParam parms) {
        PageUtil.setPageInfo(parms);
        List<ScoringRulesPO> list = scoringRulesService.queryScoringRulesList(parms);
        PageInfo<ScoringRulesPO> scoringRulesPOPageInfo = new PageInfo<>(list);
        List<ScoringRulesVO> list1 = new ArrayList<>();
        //po转vo
        for (ScoringRulesPO po : list) {
            ScoringRulesVO vo = new ScoringRulesVO();
            BeanUtils.copyProperties(po, vo);
            list1.add(vo);
        }
        PageInfo pageInfo = new PageInfo(list1);
        pageInfo.setTotal(scoringRulesPOPageInfo.getTotal());

        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS, pageInfo);
    }

    //查询详情
    @PostMapping("/queryScoringRules")
    @ResponseBody
    public ResponseBodyVO<List<ScoringRulesPO>> queryScoringRules(@RequestBody ScoringRulesParam parms) {
        if (ObjectUtil.isNull(parms.getRulesId())) {
            return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "参数RulesId不能为空，请检查");
        }
        ScoringRulesPO po = scoringRulesService.queryScoringRules(parms);
        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS, po);

    }

    //查唯一
    @PostMapping("/queryScoringRulesCount")
    @ResponseBody
    public ResponseBodyVO<List<ScoringRulesPO>> queryScoringRulesCount(@RequestBody ScoringRulesParam parms) {
        if (ObjectUtil.isNull(parms.getRuleName())) {
            return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "参数RulesName不能为空，请检查");
        }
        List<ScoringRulesPO> list = scoringRulesService.queryScoringRulesByRuleName(parms);
        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS, list);
    }

    //新增打分规则
    @PostMapping("/saveScoringRules")
    @ResponseBody
    public ResponseBodyVO<String> saveScoringRules(@RequestBody ScoringRulesPO parms) {
        ScoringRulesParam vo = new ScoringRulesParam();
        BeanUtils.copyProperties(parms, vo);
        vo.setShare("0");
        vo.setCreateUserId(AuthUtil.getCurrentUserId());
        List<ScoringRulesPO> list = scoringRulesService.queryScoringRulesByRuleName(vo);
        if (list != null && list.size() > 0) {
            return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "规则名称ruleName已存在，请重新命名");
        }
        if (ObjectUtil.isNull(parms.getRulesId())) {
            scoringRulesService.saveScoringRules(parms);
        } else {
            scoringRulesService.updateScoringRules(parms);
        }
        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS);
    }

    //分享
    @PostMapping("/fxScoringRules")
    @ResponseBody
    public ResponseBodyVO<String> fxScoringRules(@RequestBody ScoringRulesParam params) {
        if (ObjectUtil.isNull(params.getRulesId())) {
            return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "参数RulesId不能为空，请检查");
        }
        ScoringRulesPO po = scoringRulesService.queryScoringRules(params);
        params.setShare("1");
        params.setRuleName(po.getRuleName());
        List<ScoringRulesPO> list = scoringRulesService.queryScoringRulesByRuleName(params);
        if (list != null && list.size() > 0) {
            return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "规则名称ruleName已存在，请重新命名");
        }
        po.setShare("1");
        scoringRulesService.saveScoringRules(po);
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS);
    }

    //删除
    @PostMapping("/deleteScoringRules")
    @ResponseBody
    public ResponseBodyVO<String> deleteScoringRules(@RequestBody ScoringRulesPO params) {
        scoringRulesService.deleteScoringRules(params);
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS);
    }

    //测试包里面对应查询打分规则列表
    @PostMapping("/queryCsb")
    @ResponseBody
    public ResponseBodyVO<List<ScoringRulesPO>> queryCsb() {
        ScoringRulesParam params = new ScoringRulesParam();
        params.setShare("0");
        params.setCreateUserId(AuthUtil.getCurrentUserId());
        List<ScoringRulesPO> list = scoringRulesService.queryScoringRulesList(params);
        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS, list);
    }
}