package com.css.simulation.resource.scene.service;

import api.common.pojo.common.PageVO;
import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.po.home.SystemAccessPO;
import api.common.pojo.po.home.SystemServerPO;
import api.common.pojo.vo.home.AccessVO;
import api.common.pojo.vo.home.HardwareVO;
import api.common.pojo.vo.home.ServiceVO;
import api.common.pojo.vo.home.SystemServerVO;
import api.common.util.StringUtil;
import api.common.util.TimeUtil;
import com.css.simulation.resource.feign.OauthClientService;
import com.css.simulation.resource.scene.mapper.SystemAccessMapper;
import com.css.simulation.resource.scene.mapper.SystemServerMapper;
import com.css.simulation.resource.system.mapper.UserMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@Service
public class HomePageService {

    @Autowired
    SystemServerMapper systemServerMapper;

    @Autowired
    SystemAccessMapper systemAccessMapper;

    @Autowired
    UserMapper userMapper;

    @Autowired
    OauthClientService oauthClientService;


    public ResponseBodyVO<HardwareVO> selectHardware() {


        List<SystemServerPO> systemServerPOList = systemServerMapper.selectAll();


        long memorySum = systemServerPOList.stream().mapToLong(SystemServerPO::getMemoryTotal).sum();  // 内存之和
        long diskSum = systemServerPOList.stream().mapToLong(SystemServerPO::getDiskTotal).sum();  // 磁盘之和
        long cpuSum = systemServerPOList.stream().mapToLong(SystemServerPO::getDiskTotal).sum();  // cpu线程数 之和
        long gpuSum = systemServerPOList.stream().mapToLong(SystemServerPO::getDiskTotal).sum();  // 显存之和

        HardwareVO build = HardwareVO.builder()
                .serverNumber(systemServerPOList.size())
                .memoryUsage((int) systemServerPOList.stream().mapToDouble(po -> po.getMemoryUsage() * po.getMemoryTotal() / memorySum).sum() + "%")
                .diskUsage((int) systemServerPOList.stream().mapToDouble(po -> po.getDiskUsage() * po.getDiskTotal() / diskSum).sum() + "%")
                .cpuUsage((int) systemServerPOList.stream().mapToDouble(po -> po.getCpuUsage() * po.getCpuTotal() / cpuSum).sum() + "%")
                .gpuUsage((int) systemServerPOList.stream().mapToDouble(po -> po.getGpuUsage() * po.getGpuTotal() / gpuSum).sum() + "%")
                .build();

        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS, build);

    }


    public ResponseBodyVO<ServiceVO> selectService() {

        List<SystemServerPO> systemServerPOList = systemServerMapper.selectAll();
        long count = systemServerPOList.stream().filter(system -> "gpu".equals(system.getServerType())).count();

        ServiceVO build = ServiceVO.builder()
                .userNumber(userMapper.selectCount())
                .onlineNumber(oauthClientService.online().getInfo())
                .simulationNodeNumber((int) count)
                .simulationLicenseNumber(systemServerMapper.selectSumOfTaskNumber())
                .dynamicsLicenseNumber(1)   // 待定
                .build();

        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS, build);

    }


    public ResponseBodyVO<List<AccessVO>> selectAccess() {

        SystemAccessPO systemAccessPO = SystemAccessPO.builder()
                .id(StringUtil.getRandomUUID())
                .accessTime(TimeUtil.getNowForMysql())
                .build();
        systemAccessMapper.insert(systemAccessPO);

        List<AccessVO> list = new ArrayList<>();
        for (int i = 6; i > -1; i--) {
            AccessVO vo = new AccessVO();
            Map<String, Object> params = TimeUtil.getPastTime(i);
            Integer num = systemAccessMapper.selectPastAccess(params);
            vo.setToDate(params.get("toDate").toString());
            vo.setNum(num);
            list.add(vo);
        }
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS, list);

    }

    public ResponseBodyVO<PageInfo<SystemServerVO>> selectServer(PageVO pageVO) {

        PageHelper.startPage(pageVO.getCurrentPage(), pageVO.getPageSize());
        List<SystemServerPO> systemServerPOList = systemServerMapper.selectAll();
        List<SystemServerVO> systemServerVOList = new ArrayList<>();
        systemServerPOList.forEach(po -> {
            SystemServerVO vo = SystemServerVO.builder()
                    .id(po.getId())
                    .serverId(po.getServerId())
                    .serverAddress(po.getServerAddress())
                    .serverType(po.getServerType())
                    .cpuUsage((int) (po.getCpuUsage() * 100))
                    .memoryUsage((int) (po.getMemoryUsage() * 100))
                    .memoryAvailable((double) (int) (po.getMemoryAvailable() * 1.0 / 1024.0 / 1024.0 * 100) / 100)
                    .diskUsage((int) (po.getDiskUsage() * 100))
                    .diskAvailable((double) (int) (po.getDiskAvailable() * 1.0 / 1024.0 / 1024.0 * 100) / 100)
                    .taskNumber(po.getTaskNumber())
                    .build();
            systemServerVOList.add(vo);
        });

        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS, new PageInfo<>(systemServerVOList));
    }

}
