package com.css.simulation.resource.scene.service;

import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.param.MinioParameter;
import api.common.pojo.param.scene.SceneImportParam;
import api.common.pojo.param.scene.SceneNaturalNewParam;
import api.common.pojo.param.scene.SceneNaturalParam;
import api.common.pojo.po.scene.SceneNaturalPO;
import api.common.pojo.po.system.SceneImportPO;
import api.common.util.ObjectUtil;
import api.common.util.ParamUtil;
import api.common.util.TimeUtil;
import com.css.simulation.resource.common.utils.AuthUtil;
import com.css.simulation.resource.feign.FileDownService;
import com.css.simulation.resource.scene.mapper.SceneNaturalMapper;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.util.StringUtil;
import feign.Response;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;


@Slf4j
@Service
public class SceneNaturalService {

    @Resource
    private SceneNaturalMapper sceneNaturalMapper;
    @Resource
    private SystemUserSceneService systemUserSceneService;


    @Resource
    private FileDownService fileDownService;

    /**
     * 获取自然驾驶场景数据：包括切分数据和标注数据
     */
    @SneakyThrows
    public ResponseBodyVO<String> importZrjsSceneCicv(SceneNaturalParam param) {
        MinioParameter MI = new MinioParameter();
        MI.setObjectName(param.getJsonAddress());
        int idx = param.getJsonAddress().lastIndexOf("/");
        int end = param.getJsonAddress().lastIndexOf(".");
        String fileName = param.getJsonAddress().substring(idx + 1, end);
        param.setNaturalName(fileName);
        String sceneId = sceneNaturalMapper.querySceneNaturaByName(fileName);
        Response download = fileDownService.download(MI);
        String json = download.body().toString();
        ObjectMapper objMap = new ObjectMapper();
        JsonNode root = objMap.readTree(json);
        // -------------------------------- 自然环境 --------------------------------
        JsonNode naturalEnvironment = root.path("自然环境");
        // -------------------------------- 道路 --------------------------------
        JsonNode road = root.path("道路");
        // -------------------------------- 基础设施 --------------------------------
        JsonNode infrastructure = root.path("基础设施");
        // -------------------------------- 临时性操纵 --------------------------------
        JsonNode temporaryManipulation = root.path("临时性操纵");
        // -------------------------------- 交通状况 --------------------------------
        JsonNode traffic = root.path("交通状况");
        // -------------------------------- 自车行为 --------------------------------
        JsonNode selfDrivingBehavior = root.path("自车行为");
        // -------------------------------- 目标行为 --------------------------------
        JsonNode targetBehavior = root.path("目标行为");
        SceneNaturalPO sceneNaturalPO = new SceneNaturalPO();
        sceneNaturalPO = sceneNaturalPO.builder()
                .naturalId(api.common.util.StringUtil.getRandomUUID())
                .naturalName(fileName)
                .weather(getSequenceNew(naturalEnvironment, "天气情况"))
                .backlight(getSequenceNew(naturalEnvironment, "逆光"))
                .lightChange(getSequenceNew(naturalEnvironment, "隧道光线变化"))
                .roadType(getSequenceNew(road, "道路类型"))
                .roadMatrrial(getSequenceNew(road, "路面材质"))
                .drivewayNum(getSequenceNew(road, "车道数量"))
                .drivewayType(getSequenceNew(road, "车道类型"))
                .roadFlatness(getSequenceNew(road, "道路平坦程度"))
                .roadCurvature(getSequenceNew(road, "道路弯曲度"))
                .ramp(getSequenceNew(road, "匝道"))
                .intersectionType(getSequenceNew(road, "路口类型"))
                .planeIntersection(getSequenceNew(road, "道路与铁路平面交叉"))
                .bridge(getSequenceNew(road, "桥梁"))
                .tunnel(getSequenceNew(road, "隧道"))
                .speedLimit(getSequenceNew(infrastructure, "限速标志"))
                .minSpeedLimit(getSequenceNew(infrastructure, "最低限速标志"))
                .noEntry(getSequenceNew(infrastructure, "禁止通行"))
                .noStopping(getSequenceNew(infrastructure, "禁止停车"))
                .leftLaneLine(getSequenceNew(infrastructure, "左侧车道线"))
                .rightLaneLine(getSequenceNew(infrastructure, "右侧车道线"))
                .conductorMarking(getSequenceNew(infrastructure, "导线标线及标志"))
                .pedestrianCrossing(getSequenceNew(infrastructure, "人行横道"))
                .trafficLight(getSequenceNew(infrastructure, "交通信号灯"))
                .decelerationMarking(getSequenceNew(infrastructure, "减速标线"))
                .pavementCondition(getSequenceNew(temporaryManipulation, "路面状况"))
                .naturalDisaster(getSequenceNew(temporaryManipulation, "自然灾害"))
                .roadSafetySigns(getSequenceNew(temporaryManipulation, "道路施工安全标识"))
                .safetyWarningBoard(getSequenceNew(temporaryManipulation, "三角安全警示牌"))
                .trafficAccident(getSequenceNew(traffic, "交通事故"))
                .violation(getSequenceNew(traffic, "违规"))
                .specialVehicleYield(getSequenceNew(traffic, "特种车辆让行"))
                .patency(getSequenceNew(traffic, "通畅情况"))
                .doubleFlashingCar(getSequenceNew(traffic, "双闪车辆"))
                .selfBehavior(getSequenceNew(selfDrivingBehavior))
                .targetBehavior(getSequenceNew(targetBehavior))
                .maxTime(root.path("max_time").asText())
                .isDeleted("0")
                .build();
        if (null != param.getJsonAddress() && !param.getJsonAddress().equals("")) {
            sceneNaturalPO.setJsonAddress(param.getJsonAddress());
        }
        if (null != param.getXoscAddress() && !param.getXoscAddress().equals("")) {
            sceneNaturalPO.setXoscAddress(param.getXoscAddress());
        }
        if (null != param.getXodrAddress() && !param.getXodrAddress().equals("")) {
            sceneNaturalPO.setXodrAddress(param.getXodrAddress());
        }
        if (null != param.getOsgbAddress() && !param.getOsgbAddress().equals("")) {
            sceneNaturalPO.setOsgbAddress(param.getOsgbAddress());
        }
        if (null != param.getVideoAddress() && !param.getVideoAddress().equals("")) {
            sceneNaturalPO.setVideoAddress(param.getVideoAddress());
        }
        if (null != param.getVideoPreview() && !param.getVideoPreview().equals("")) {
            sceneNaturalPO.setVideoPreview(param.getVideoPreview());
        }

        if (ObjectUtil.isNull(sceneId)) {
            // -------------------------------- 保存数据到 mysql --------------------------------
            sceneNaturalPO.setCreateTime(TimeUtil.getNowForMysql());
            sceneNaturalPO.setCreateUserId(AuthUtil.getCurrentUserId());
            sceneNaturalPO.setModifyTime(TimeUtil.getNowForMysql());
            sceneNaturalMapper.saveSceneNatural(sceneNaturalPO);
          //  return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "该场景编号" + fileName + "已存在，请检查");
        }else{
            // -------------------------------- 修改数据到 mysql --------------------------------
            sceneNaturalPO.setModifyUserId(AuthUtil.getCurrentUserId());
            sceneNaturalPO.setModifyTime(TimeUtil.getNowForMysql());
            sceneNaturalPO.setNaturalId(sceneId);
            sceneNaturalMapper.updateSceneNatural(sceneNaturalPO);
        }
        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS);
    }

    public String getSequenceNew(JsonNode jsonObject, String field) throws Exception {
        if (jsonObject == null) {
            return "无法确定";
        }
        JsonNode jsonArray = jsonObject.path(field);
        StringBuilder sequence = new StringBuilder();
        for (int i = 0; i < jsonArray.size(); i++) {
            String type_ = jsonArray.path(i).path("type_").asText();
            if (StringUtil.isNotEmpty(type_)) {
                if (i == 0) {
                    sequence.append(type_);
                    continue;
                }
                if (!sequence.toString().contains(type_))
                    sequence.append(",").append(type_);
            }
        }
        String s = sequence.toString();
        if (StringUtil.isEmpty(s))
            return "无法确定";
        else
            return s;
    }

    public String getSequenceNew(JsonNode jsonArray) throws Exception {
        if (jsonArray == null) {
            return "无法确定";
        }
        StringBuilder sequence = new StringBuilder();
        for (int i = 0; i < jsonArray.size(); i++) {
            String type_ = jsonArray.path(i).path("type_").asText();
            if (StringUtil.isNotEmpty(type_)) {
                if (i == 0) {
                    sequence.append(type_);
                    continue;
                }
                if (!sequence.toString().contains(type_))
                    sequence.append(",").append(type_);
            }
        }
        String s = sequence.toString();
        if (StringUtil.isEmpty(s))
            return "无法确定";
        else
            return s;
    }

    public List<SceneNaturalPO> querySceneNaturalList(SceneNaturalNewParam params) {
        SceneNaturalParam po = new SceneNaturalParam();
        String naturalName = params.getNaturalName();      // 场景编号
        String[][] naturalEnvironment = params.getNaturalEnvironment(); //自然环境
        String[][] road = params.getRoad(); //道路
        String[][] infrastructure = params.getInfrastructure(); //基础设施
        String[][] temporaryOperation = params.getTemporaryOperation(); //临时性操作
        String[][] trafficCondition = params.getTrafficCondition(); //交通状况
        String[][] selfBehavior = params.getSelfBehavior();//自车行为
        String[][] targetBehavior = params.getTargetBehavior(); //目标行为
        //判断下拉选项是否为空
        if(ObjectUtil.isNotNull(naturalName)||(naturalEnvironment!=null&&naturalEnvironment.length>0)||(road!=null&&road.length>0)
        ||(infrastructure!=null&&infrastructure.length>0)||(temporaryOperation!=null&&temporaryOperation.length>0)||(trafficCondition!=null&&trafficCondition.length>0)||
         (selfBehavior!=null&&selfBehavior.length>0)||(targetBehavior!=null&&targetBehavior.length>0)||(params.getIds()!=null&&params.getIds().length>0)){
            po.setXlk("1");
        }
        SceneNaturalParam poBq = new SceneNaturalParam();
        String[][] highSpeed=params.getHighSpeed() ;//高速
        String[][] ramp=params.getRamp();//匝道
        String[][] tunnel=params.getTunnel();//隧道
        String[][] cutIn=params.getCutIn();//切入
        String[][] cutOut=params.getCutOut();//切出
        String[][] laneChange=params.getLaneChange();//变道
        String[][] turnAround=params.getTurnAround();//掉头
        //判断标签是否为空
        if((highSpeed!=null&&highSpeed.length>0)||(ramp!=null&&ramp.length>0)
                ||(tunnel!=null&&tunnel.length>0)||(cutIn!=null&&cutIn.length>0)||(cutOut!=null&&cutOut.length>0)||
                (laneChange!=null&&laneChange.length>0)||(turnAround!=null&&turnAround.length>0)){
            po.setBq("1");
        }

        if (highSpeed != null && highSpeed.length > 0) {
            ParamUtil.arrConvertObj(highSpeed, poBq);
        }
        if (ramp != null && ramp.length > 0) {
            ParamUtil.arrConvertObj(ramp, poBq);
        }
        if (tunnel != null && tunnel.length > 0) {
            ParamUtil.arrConvertObj(tunnel, poBq);
        }
        if (cutIn != null && cutIn.length > 0) {
            ParamUtil.arrConvertObj(cutIn, poBq);
        }
        if (cutOut != null && cutOut.length > 0) {
            ParamUtil.arrConvertObj(cutOut, poBq);
        } if (turnAround != null && turnAround.length > 0) {
            ParamUtil.arrConvertObj(turnAround, poBq);
        }
        if (laneChange != null && laneChange.length > 0) {
            ParamUtil.arrConvertObj(laneChange, poBq);
        }


        if (ObjectUtil.isNotNull(params.getIds())) {
            po.setIds(params.getIds());
        }
        if (ObjectUtil.isNotNull(naturalName)) {
            po.setNaturalName(naturalName);
        }
        if (naturalEnvironment != null && naturalEnvironment.length > 0) {
            ParamUtil.arrConvertObj(naturalEnvironment, po);
        }
        if (road != null && road.length > 0) {
            ParamUtil.arrConvertObj(road, po);
        }
        if (infrastructure != null && infrastructure.length > 0) {
            ParamUtil.arrConvertObj(infrastructure, po);
        }
        if (temporaryOperation != null && temporaryOperation.length > 0) {
            ParamUtil.arrConvertObj(temporaryOperation, po);
        }
        if (trafficCondition != null && trafficCondition.length > 0) {
            ParamUtil.arrConvertObj(trafficCondition, po);
        }
        if (selfBehavior != null && selfBehavior.length > 0) {
            ParamUtil.arrConvertObj(selfBehavior, po);
            for (String[] arr : selfBehavior) {
                if (arr != null && arr.length == 1) {
                    List list = po.getSelfBehavior();
                    if (list == null) {
                        List newList = new ArrayList();
                        newList.add(arr[0]);
                        po.setSelfBehavior(newList);
                        ;
                    } else {

                        list.add(arr[0]);
                        po.setSelfBehavior(list);
                    }
                }
            }
        }
        if (targetBehavior != null && targetBehavior.length > 0) {
            ParamUtil.arrConvertObj(targetBehavior, po);
        }

     //获取权限并赋值
     /* List<String> listType=  systemUserSceneService.querySystemUserSceneByType(DictConstants.SCENE_NATURAL);
        if(listType!=null&&listType.size()>0){
            po.setAllIds(listType);
        }else{
            List<String> listA=new ArrayList<>();
            listA.add("没有权限");
            po.setAllIds(listA);
        }*/
         Map<String,SceneNaturalParam> map=new HashMap<String,SceneNaturalParam>();
         map.put("po",po);
         map.put("poBq",poBq);
        //List<SceneNaturalPO> list = sceneNaturalMapper.querySceneNaturalList(po);
        //只有标签,或下拉框，或者两者都为空
        List<SceneNaturalPO> list=new ArrayList<>();
        if((po.getXlk().equals("0")&&po.getBq().equals("0"))||(po.getXlk().equals("1")&&po.getBq().equals("0"))){
            list = sceneNaturalMapper.querySceneNaturalList(po);
        }else if((po.getXlk().equals("0")&&po.getBq().equals("1"))) {
             list = sceneNaturalMapper.querySceneNaturalListByBq(map);
        }else{
            list = sceneNaturalMapper.querySceneNaturalListByBqAndXlk(map);
        }
        //list = sceneNaturalMapper.querySceneNaturalListByBq(map);
        //List<SceneNaturalPO> list = sceneNaturalMapper.querySceneNaturalList(map);
        for (SceneNaturalPO vo : list) {
            if (vo.getRoadType().equals("高速")) {
                if (ObjectUtil.isNull(vo.getLabel())) {
                    vo.setLabel("高速");
                } else {
                    vo.setLabel(vo.getLabel() + ",高速");
                }
            }
            if (vo.getRamp().equals("是")) {
                if (ObjectUtil.isNull(vo.getLabel())) {
                    vo.setLabel("匝道");
                } else {
                    vo.setLabel(vo.getLabel() + ",匝道");
                }
            }
            if (vo.getTunnel().equals("是")) {
                if (ObjectUtil.isNull(vo.getLabel())) {
                    vo.setLabel("隧道");
                } else {
                    vo.setLabel(vo.getLabel() + ",隧道");
                }
            }
            if (vo.getTargetBehavior().indexOf("机动车从左侧切入成功")>-1 ||vo.getTargetBehavior().indexOf("机动车从右侧切入成功")>-1) {
                if (ObjectUtil.isNull(vo.getLabel())){
                    vo.setLabel("切入");
                } else {
                    vo.setLabel(vo.getLabel() + ",切入");
                }
            }
            if (vo.getTargetBehavior().equals("机动车向左侧切出成功") ||vo.getTargetBehavior().equals("机动车向右侧切出成功")) {
                if (ObjectUtil.isNull(vo.getLabel())){
                    vo.setLabel("切出");
                } else {
                    vo.setLabel(vo.getLabel() + ",切出");
                }
            }
            if (vo.getSelfBehavior().indexOf("直路掉头")>-1 ||vo.getSelfBehavior().indexOf("路口掉头")>-1){
                if (ObjectUtil.isNull(vo.getLabel())){
                    vo.setLabel("掉头");
                } else {
                    vo.setLabel(vo.getLabel() + ",掉头");
                }
            }
            if (vo.getSelfBehavior().indexOf("向左变道成功") >-1||vo.getSelfBehavior().equals("向右变道成功")||vo.getSelfBehavior().indexOf("向左连续变道")>-1||vo.getSelfBehavior().indexOf("向右连续变道")>-1||vo.getSelfBehavior().indexOf("向左变道超车")>-1||vo.getSelfBehavior().indexOf("向右变道超车")>-1) {
                if (ObjectUtil.isNull(vo.getLabel())){
                    vo.setLabel("变道");
                } else {
                    vo.setLabel(vo.getLabel() + ",变道");
                }
            }
        }
        return list;
    }

    public void deleteSceneNatural(SceneNaturalPO params) {
        params.setIsDeleted("1");
        params.setModifyTime(TimeUtil.getNowForMysql());
        params.setModifyUserId(AuthUtil.getCurrentUserId());
        sceneNaturalMapper.deleteSceneNatural(params);
       // systemUserSceneService.deleteSystemUserSceneBySceneId(params.getNaturalId());
    }
    public Integer querySceneNumBySy() {
        SceneNaturalParam params=new SceneNaturalParam();
        params.setCreateUserId(AuthUtil.getCurrentUserId());
       return sceneNaturalMapper.querySceneNumBySy(params);
    }



    /**
     * 获取自然场景数据：
     */
    public SceneImportPO importMiNio(SceneImportParam parms) {
        SceneImportPO sceneImportPO=new  SceneImportPO();
        sceneImportPO.setId(parms.getId());
        try {
            MinioParameter MI = new MinioParameter();
            MI.setObjectName(parms.getMinioDirectory());
            List<String> list = fileDownService.listDeepOne(MI).getInfo();
            String OsgbPath = null;
            String XodrPath = null;
            int successNum = 0;
            int falseNum = 0;
            String errorMessage = "";
            for (String filePath : list) {
                if (filePath.indexOf("/OSGB") != -1) {
                    OsgbPath = filePath;
                } else if (filePath.indexOf("/XODR") != -1) {
                    XodrPath = filePath;
                }
            }
            for (String filePath : list) {
                if (filePath.indexOf("/Scenarios") != -1) {
                    MI.setObjectName(filePath);
                    List<String> listScene = fileDownService.listDeepOne(MI).getInfo();
                    for (String scenePath : listScene) {
                        try {
                            MI.setObjectName(scenePath);
                            List<String> listAderss = fileDownService.list(MI).getInfo();
                            SceneNaturalPO sceneNaturalPO = new SceneNaturalPO();
                            String isupdate = null;
                            for (String adress : listAderss) {
                                if (adress.indexOf(".json") != -1) {
                                    MI.setObjectName(adress);
                                    Response download = fileDownService.download(MI);
                                    // -------------------------------- label.json --------------------------------
                                    String json = download.body().toString();
                                    ObjectMapper objMap = new ObjectMapper();
                                    JsonNode root = objMap.readTree(json);
                                    //判断场景名称唯一
                                    int idx = adress.lastIndexOf("/");
                                    int end = adress.lastIndexOf(".");
                                    String fileName = adress.substring(idx + 1, end);
                                    String sceneId = sceneNaturalMapper.querySceneNaturaByName(fileName);
                                    String osgbAdress = OsgbPath + "/" + root.path("osgb").asText();
                                    String xodrAdress = XodrPath + "/" + root.path("xodr").asText();
                                    // -------------------------------- 自然环境 --------------------------------
                                    JsonNode naturalEnvironment = root.path("自然环境");
                                    // -------------------------------- 道路 --------------------------------
                                    JsonNode road = root.path("道路");
                                    // -------------------------------- 基础设施 --------------------------------
                                    JsonNode infrastructure = root.path("基础设施");
                                    // -------------------------------- 临时性操纵 --------------------------------
                                    JsonNode temporaryManipulation = root.path("临时性操纵");
                                    // -------------------------------- 交通状况 --------------------------------
                                    JsonNode traffic = root.path("交通状况");
                                    // -------------------------------- 自车行为 --------------------------------
                                    JsonNode selfDrivingBehavior = root.path("自车行为");
                                    // -------------------------------- 目标行为 --------------------------------
                                    JsonNode targetBehavior = root.path("目标行为");
                                    sceneNaturalPO.setNaturalId(api.common.util.StringUtil.getRandomUUID());
                                    sceneNaturalPO.setNaturalName(fileName);
                                    sceneNaturalPO.setWeather(getSequenceNew(naturalEnvironment, "天气情况"));
                                    sceneNaturalPO.setBacklight(getSequenceNew(naturalEnvironment, "逆光"));
                                    sceneNaturalPO.setLightChange(getSequenceNew(naturalEnvironment, "隧道光线变化"));
                                    sceneNaturalPO.setRoadType(getSequenceNew(road, "道路类型"));
                                    sceneNaturalPO.setRoadMatrrial(getSequenceNew(road, "路面材质"));
                                    sceneNaturalPO.setDrivewayNum(getSequenceNew(road, "车道数量"));
                                    sceneNaturalPO.setDrivewayType(getSequenceNew(road, "车道类型"));
                                    sceneNaturalPO.setRoadFlatness(getSequenceNew(road, "道路平坦程度"));
                                    sceneNaturalPO.setRoadCurvature(getSequenceNew(road, "道路弯曲度"));
                                    sceneNaturalPO.setRamp(getSequenceNew(road, "匝道"));
                                    sceneNaturalPO.setIntersectionType(getSequenceNew(road, "路口类型"));
                                    sceneNaturalPO.setPlaneIntersection(getSequenceNew(road, "道路与铁路平面交叉"));
                                    sceneNaturalPO.setBridge(getSequenceNew(road, "桥梁"));
                                    sceneNaturalPO.setTunnel(getSequenceNew(road, "隧道"));
                                    sceneNaturalPO.setSpeedLimit(getSequenceNew(infrastructure, "限速标志"));
                                    sceneNaturalPO.setMinSpeedLimit(getSequenceNew(infrastructure, "最低限速标志"));
                                    sceneNaturalPO.setNoEntry(getSequenceNew(infrastructure, "禁止通行"));
                                    sceneNaturalPO.setNoStopping(getSequenceNew(infrastructure, "禁止停车"));
                                    sceneNaturalPO.setLeftLaneLine(getSequenceNew(infrastructure, "左侧车道线"));
                                    sceneNaturalPO.setRightLaneLine(getSequenceNew(infrastructure, "右侧车道线"));
                                    sceneNaturalPO.setConductorMarking(getSequenceNew(infrastructure, "导线标线及标志"));
                                    sceneNaturalPO.setPedestrianCrossing(getSequenceNew(infrastructure, "人行横道"));
                                    sceneNaturalPO.setTrafficLight(getSequenceNew(infrastructure, "交通信号灯"));
                                    sceneNaturalPO.setDecelerationMarking(getSequenceNew(infrastructure, "减速标线"));
                                    sceneNaturalPO.setPavementCondition(getSequenceNew(temporaryManipulation, "路面状况"));
                                    sceneNaturalPO.setNaturalDisaster(getSequenceNew(temporaryManipulation, "自然灾害"));
                                    sceneNaturalPO.setRoadSafetySigns(getSequenceNew(temporaryManipulation, "道路施工安全标识"));
                                    sceneNaturalPO.setSafetyWarningBoard(getSequenceNew(temporaryManipulation, "三角安全警示牌"));
                                    sceneNaturalPO.setTrafficAccident(getSequenceNew(traffic, "交通事故"));
                                    sceneNaturalPO.setViolation(getSequenceNew(traffic, "违规"));
                                    sceneNaturalPO.setSpecialVehicleYield(getSequenceNew(traffic, "特种车辆让行"));
                                    sceneNaturalPO.setPatency(getSequenceNew(traffic, "通畅情况"));
                                    sceneNaturalPO.setDoubleFlashingCar(getSequenceNew(traffic, "双闪车辆"));
                                    sceneNaturalPO.setSelfBehavior(getSequenceNew(selfDrivingBehavior));
                                    sceneNaturalPO.setTargetBehavior(getSequenceNew(targetBehavior));
                                    sceneNaturalPO.setMaxTime(root.path("max_time").asText());
                                             sceneNaturalPO.setIsDeleted("0");
                                    if(ObjectUtil.isNull(sceneNaturalPO.getOsgbAddress())){
                                        sceneNaturalPO.setOsgbAddress(osgbAdress);
                                    }
                                    if(ObjectUtil.isNull(sceneNaturalPO.getXodrAddress())){
                                        sceneNaturalPO.setXodrAddress(xodrAdress);
                                    }
                                    if (ObjectUtil.isNull(sceneId)) {
                                        isupdate = "0";
                                    } else {
                                        isupdate = "1";
                                        sceneNaturalPO.setNaturalId(sceneId);
                                    }
                                }
                                if (adress.indexOf(".json") != -1) {
                                    sceneNaturalPO.setJsonAddress(adress);
                                } else if (adress.indexOf(".xml") != -1 || adress.indexOf(".xosc") != -1) {
                                    sceneNaturalPO.setXoscAddress(adress);
                                } else if (adress.indexOf(".xodr") != -1) {
                                    sceneNaturalPO.setXodrAddress(adress);
                                } else if (adress.indexOf(".osgb") != -1) {
                                    sceneNaturalPO.setOsgbAddress(adress);
                                } else if (adress.indexOf("simulation.mp4") != -1) {
                                    sceneNaturalPO.setVideoAddress(adress);
                                }else if (adress.indexOf(".mp4") != -1) {
                                    sceneNaturalPO.setVideoPreview(adress);
                                }
                            }
                            if (isupdate.equals("0")) {
                                // -------------------------------- 保存数据到 mysql --------------------------------
                                sceneNaturalPO.setCreateTime(TimeUtil.getNowForMysql());
                                sceneNaturalPO.setCreateUserId(AuthUtil.getCurrentUserId());
                                sceneNaturalPO.setModifyTime(TimeUtil.getNowForMysql());
                                sceneNaturalMapper.saveSceneNatural(sceneNaturalPO);
                            } else if (isupdate.equals("1")) {
                                // -------------------------------- 修改数据到 mysql --------------------------------
                                sceneNaturalPO.setModifyTime(TimeUtil.getNowForMysql());
                                sceneNaturalPO.setModifyUserId(AuthUtil.getCurrentUserId());
                                sceneNaturalMapper.updateSceneNatural(sceneNaturalPO);
                            }
                            successNum = successNum + 1;
                        } catch (Exception e) {
                            if (ObjectUtil.isNull(errorMessage)) {
                                errorMessage = scenePath;
                            } else {
                                errorMessage = errorMessage + ";" + scenePath;
                            }
                            falseNum = falseNum + 1;
                        }
                    }
                }
            }
            sceneImportPO.setStatus("4");
            sceneImportPO.setSuccessNum(successNum);
            sceneImportPO.setFalseNum(falseNum);
            sceneImportPO.setErrorMessage(errorMessage);
          //  sceneImportTaskService.updateSceneImportTask(sceneImportTaskPO);
            return sceneImportPO;
        }catch (Exception e){
            sceneImportPO.setStatus("2");
           return sceneImportPO;
        }
    }

}
