package com.css.simulation.resource.scene.service;

import api.common.pojo.param.scene.ScoringRulesParam;
import api.common.pojo.po.scene.ScoringRulesPO;
import api.common.util.StringUtil;
import api.common.util.TimeUtil;
import com.css.simulation.resource.common.utils.AuthUtil;
import com.css.simulation.resource.scene.mapper.ScoringRulesMapper;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import java.util.List;

@Slf4j
@Service
public class ScoringRulesService {

    @Resource
    private ScoringRulesMapper scoringRulesMapper;

    /**
     * 打分规则数据录入：
     */
    @SneakyThrows
    public void saveScoringRules(ScoringRulesPO params) {
        params.setCreateTime(TimeUtil.getNowForMysql());
        params.setModifyTime(TimeUtil.getNowForMysql());
        params.setRulesId(StringUtil.getRandomUUID());
        params.setRulesCode(StringUtil.getRandomCode());
        params.setCreateUserId(AuthUtil.getCurrentUserId());
        params.setIsDeleted("0");
        scoringRulesMapper.saveScoringRules(params);
    }

    @SneakyThrows
    public List<ScoringRulesPO> queryScoringRulesList(ScoringRulesParam params) {
        if (params != null && params.getShare() != null && params.getShare().equals("0")) {
            params.setCreateUserId(AuthUtil.getCurrentUserId());
        }
        List<ScoringRulesPO> list = scoringRulesMapper.queryScoringRulesList(params);
        return list;
    }

    @SneakyThrows
    public ScoringRulesPO queryScoringRules(ScoringRulesParam params) {
        ScoringRulesPO Po = scoringRulesMapper.queryScoringRules(params);
        return Po;
    }

    @SneakyThrows
    public List<ScoringRulesPO> queryScoringRulesByRuleName(ScoringRulesParam params) {
        if (params.getShare().equals("0")) {
            params.setCreateUserId(AuthUtil.getCurrentUserId());
        }
        return scoringRulesMapper.queryScoringRulesByRuleName(params);
    }

    @SneakyThrows
    public void updateScoringRules(ScoringRulesPO params) {
        params.setModifyTime(TimeUtil.getNowForMysql());
        params.setModifyUserId(AuthUtil.getCurrentUserId());
        scoringRulesMapper.updateScoringRules(params);
    }

    @SneakyThrows
    public void deleteScoringRules(ScoringRulesPO params) {
        params.setIsDeleted("1");
        params.setModifyTime(TimeUtil.getNowForMysql());
        params.setModifyUserId(AuthUtil.getCurrentUserId());
        scoringRulesMapper.updateScoringRules(params);
    }
}
