package com.css.simulation.resource.scene.service;

import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.param.MinioParameter;
import api.common.pojo.param.scene.SceneImportParam;
import api.common.pojo.param.scene.StandardsRegulationsParam;
import api.common.pojo.po.scene.StandardsRegulationsPO;
import api.common.pojo.po.system.SceneImportPO;
import api.common.util.ObjectUtil;
import api.common.util.StringUtil;
import api.common.util.TimeUtil;
import com.css.simulation.resource.common.utils.AuthUtil;
import com.css.simulation.resource.feign.FileDownService;
import com.css.simulation.resource.scene.mapper.StandardsRegulationsMapper;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import feign.Response;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

@Slf4j
@Service
public class StandardsRegulationsService {

    @Resource
    private StandardsRegulationsMapper standardsRegulationsMapper;

    @Resource
    private FileDownService fileDownService;
    @Resource
    private SystemUserSceneService systemUserSceneService;
    /**
     * 获取标准法规场景数据：
     */
    @SneakyThrows
    public ResponseBodyVO<String> importBzFg(StandardsRegulationsParam param) {

        MinioParameter MI = new MinioParameter();
        MI.setObjectName(param.getJsonAddress());
        Response download = fileDownService.download(MI);
        String json = download.body().toString();
        ObjectMapper objMap = new ObjectMapper();
        JsonNode root = objMap.readTree(json);
        String sceneName = root.path("场景名称").asText();
       String sceneId = standardsRegulationsMapper.queryStandardsRegulationsByName(sceneName);

        StandardsRegulationsPO standardsRegulationsPO = new StandardsRegulationsPO();
        standardsRegulationsPO = standardsRegulationsPO.builder()
                .regulationsId(StringUtil.getRandomUUID())
                .sceneName(sceneName)
                .regulationType(root.path("法规类型").asText())
                .standardType(root.path("标准类型").asText())
                .maxTime(root.path("max_time").asText())
                .isDeleted("0")
                .build();
        if (null != param.getJsonAddress() && !param.getJsonAddress().equals("")) {
            standardsRegulationsPO.setJsonAddress(param.getJsonAddress());
        }
        if (null != param.getXmlAddress() && !param.getXmlAddress().equals("")) {
            standardsRegulationsPO.setXmlAddress(param.getXmlAddress());
        }
        if (null != param.getXodrAddress() && !param.getXodrAddress().equals("")) {
            standardsRegulationsPO.setXodrAddress(param.getXodrAddress());
        }
        if (null != param.getOsgbAddress() && !param.getOsgbAddress().equals("")) {
            standardsRegulationsPO.setOsgbAddress(param.getOsgbAddress());
        }
        if (null != param.getVideoAddress() && !param.getVideoAddress().equals("")) {
            standardsRegulationsPO.setVideoAddress(param.getVideoAddress());
        }
        if (null != param.getVideoPreview() && !param.getVideoPreview().equals("")) {
            standardsRegulationsPO.setVideoPreview(param.getVideoPreview());
        }

        if (ObjectUtil.isNull(sceneId)) {
            // -------------------------------- 保存数据到 mysql --------------------------------
            standardsRegulationsPO.setCreateTime(TimeUtil.getNowForMysql());
            standardsRegulationsPO.setModifyTime(TimeUtil.getNowForMysql());
            standardsRegulationsPO.setCreateUserId(AuthUtil.getCurrentUserId());
            standardsRegulationsMapper.saveStandardsRegulations(standardsRegulationsPO);

           // return new ResponseBodyVO(ResponseBodyVO.Response.CLIENT_FAILURE, "该场景名称" + sceneName + "已存在，请检查");
        }else{
            // -------------------------------- 修改数据到 mysql --------------------------------
            standardsRegulationsPO.setRegulationsId(sceneId);
            standardsRegulationsPO.setModifyTime(TimeUtil.getNowForMysql());
            standardsRegulationsPO.setModifyUserId(AuthUtil.getCurrentUserId());
            standardsRegulationsMapper.updateStandardsRegulations(standardsRegulationsPO);

        }


        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS);
    }

    //查看列表
    public List<StandardsRegulationsPO> queryStandardsRegulationsList(StandardsRegulationsParam params) {
        if(ObjectUtil.isNotNull(params.getSceneName()) || (params.getRegulationType()!=null&&params.getRegulationType().size()>0)||ObjectUtil.isNotNull(params.getStandardType())||ObjectUtil.isNotNull(params.getStandardType())
                ||(params.getIds()!=null&&params.getIds().length>0)){
            params.setXlk("1");
        }
        if(params.getLabel()!=null&&params.getLabel().size()>0){
            params.setBq("1");
        }
        List<StandardsRegulationsPO> list =new ArrayList<>();

        if((params.getXlk().equals("1")&&params.getBq().equals("1"))||(params.getXlk().equals("0")&&params.getBq().equals("0"))||(params.getXlk().equals("1")&&params.getBq().equals("0"))){
            list =  standardsRegulationsMapper.queryStandardsRegulationsList(params);
        }/*else if(params.getXlk().equals("1")&&params.getBq().equals("0")){
            list =  standardsRegulationsMapper.queryStandardsRegulationsList(params);
        }*/else if(params.getXlk().equals("0")&&params.getBq().equals("1")){
            list =  standardsRegulationsMapper.queryStandardsRegulationsListByBq(params);
        }


       /* if(params.getLabel()!=null&&params.getLabel().size()>0){
            if(params.getRegulationType()!=null&&params.getRegulationType().size()>0){
                List<String> regulationType= params.getRegulationType();
                regulationType.addAll(params.getLabel());
                params.setRegulationType(regulationType);
            }else{
                List<String> regulationType=new ArrayList<>();
                regulationType.addAll(params.getLabel());
                params.setRegulationType(regulationType);
            }
        }*/

        //获取权限并赋值
      /*  List<String> listType=  systemUserSceneService.querySystemUserSceneByType(DictConstants.SCENE_STANDARD);
        if(listType!=null&&listType.size()>0){
            params.setAllIds(listType);
        }else{
            List<String> listA=new ArrayList<>();
            listA.add("没有权限");
            params.setAllIds(listA);
        }*/
        return list;
    }

    public void deleteStandardsRegulations(StandardsRegulationsPO params) {
        params.setIsDeleted("1");
        params.setModifyTime(TimeUtil.getNowForMysql());
        params.setModifyUserId(AuthUtil.getCurrentUserId());
        standardsRegulationsMapper.deleteStandardsRegulations(params);
       // systemUserSceneService.deleteSystemUserSceneBySceneId(params.getRegulationsId());
    }


    /**
     * 获取交通事故场景数据：
     */
    public SceneImportPO importMiNio(SceneImportParam parms) {
        SceneImportPO sceneImportPO=new  SceneImportPO();
        sceneImportPO.setId(parms.getId());
        try {
            MinioParameter MI = new MinioParameter();
            MI.setObjectName(parms.getMinioDirectory());
            List<String> list = fileDownService.listDeepOne(MI).getInfo();
            String OsgbPath = null;
            String XodrPath = null;
            int successNum = 0;
            int falseNum = 0;
            String errorMessage = "";
            for (String filePath : list) {
                if (filePath.indexOf("/OSGB") != -1) {
                    OsgbPath = filePath;
                } else if (filePath.indexOf("/XODR") != -1) {
                    XodrPath = filePath;
                }
            }
            for (String filePath : list) {
                if (filePath.indexOf("/Scenarios") != -1) {
                    MI.setObjectName(filePath);
                    List<String> listScene = fileDownService.listDeepOne(MI).getInfo();
                    for (String scenePath : listScene) {
                        try {
                            MI.setObjectName(scenePath);
                            List<String> listAderss = fileDownService.list(MI).getInfo();
                            StandardsRegulationsPO standardsRegulationsPO = new StandardsRegulationsPO();
                            String isupdate = null;
                            for (String adress : listAderss) {
                                if (adress.indexOf(".json") != -1) {
                                    MI.setObjectName(adress);
                                    Response download = fileDownService.download(MI);
                                    // -------------------------------- label.json --------------------------------
                                    String json = download.body().toString();
                                    ObjectMapper objMap = new ObjectMapper();
                                    JsonNode root = objMap.readTree(json);
                                    //判断场景名称唯一
                                    String sceneName = root.path("场景名称").asText();
                                    String sceneId = standardsRegulationsMapper.queryStandardsRegulationsByName(sceneName);
                                    String osgbAdress = OsgbPath + "/" + root.path("osgb").asText();
                                    String xodrAdress = XodrPath + "/" + root.path("xodr").asText();
                                    standardsRegulationsPO = standardsRegulationsPO.builder()
                                            .regulationsId(StringUtil.getRandomUUID())
                                            .sceneName(sceneName)
                                            .regulationType(root.path("法规类型").asText())
                                            .standardType(root.path("标准类型").asText())
                                            .maxTime(root.path("max_time").asText())
                                            .xodrAddress(xodrAdress)
                                            .osgbAddress(osgbAdress)
                                            .isDeleted("0")
                                            .build();
                                    if (ObjectUtil.isNull(sceneId)) {
                                        isupdate = "0";
                                    } else {
                                        isupdate = "1";
                                        standardsRegulationsPO.setRegulationsId(sceneId);
                                    }
                                }
                                if (adress.indexOf(".json") != -1) {
                                    standardsRegulationsPO.setJsonAddress(adress);
                                } else if (adress.indexOf(".xml") != -1 || adress.indexOf(".xosc") != -1) {
                                    standardsRegulationsPO.setXmlAddress(adress);
                                } else if (adress.indexOf(".xodr") != -1) {
                                    standardsRegulationsPO.setXodrAddress(adress);
                                } else if (adress.indexOf(".osgb") != -1) {
                                    standardsRegulationsPO.setOsgbAddress(adress);
                                } else if (adress.indexOf(".mp4") != -1) {
                                    standardsRegulationsPO.setVideoAddress(adress);
                                }
                            }
                            if (isupdate.equals("0")) {
                                // -------------------------------- 保存数据到 mysql --------------------------------
                                standardsRegulationsPO.setCreateTime(TimeUtil.getNowForMysql());
                                standardsRegulationsPO.setCreateUserId(AuthUtil.getCurrentUserId());
                                standardsRegulationsPO.setModifyTime(TimeUtil.getNowForMysql());
                                standardsRegulationsMapper.saveStandardsRegulations(standardsRegulationsPO);
                            } else if (isupdate.equals("1")) {
                                // -------------------------------- 修改数据到 mysql --------------------------------
                                standardsRegulationsPO.setModifyTime(TimeUtil.getNowForMysql());
                                standardsRegulationsPO.setModifyUserId(AuthUtil.getCurrentUserId());
                                standardsRegulationsMapper.updateStandardsRegulations(standardsRegulationsPO);
                            }
                            successNum = successNum + 1;
                        } catch (Exception e) {
                            if (ObjectUtil.isNull(errorMessage)) {
                                errorMessage = scenePath;
                            } else {
                                errorMessage = errorMessage + ";" + scenePath;
                            }
                            falseNum = falseNum + 1;
                        }
                    }
                }
            }
            sceneImportPO.setStatus("4");
            sceneImportPO.setSuccessNum(successNum);
            sceneImportPO.setFalseNum(falseNum);
            sceneImportPO.setErrorMessage(errorMessage);
            return sceneImportPO;
        }catch (Exception e){
            sceneImportPO.setStatus("2");
            return sceneImportPO;
        }
    }
}
