package com.css.simulation.resource.scene.service;

import api.common.pojo.param.scene.ScoringRulesParam;
import api.common.pojo.param.scene.SystemScenePackageParam;
import api.common.pojo.po.scene.*;
import api.common.pojo.vo.scene.PackageVO;
import api.common.pojo.vo.scene.SystemScenePackageVO;
import api.common.pojo.vo.scene.SystemUserSceneVO;
import api.common.pojo.vo.scene.UserSceneVO;
import api.common.util.ObjectUtil;
import api.common.util.StringUtil;
import api.common.util.TimeUtil;
import com.css.simulation.resource.common.utils.AuthUtil;
import com.css.simulation.resource.scene.mapper.ScoringRulesMapper;
import com.css.simulation.resource.scene.mapper.SystemScenePackageMapper;
import com.css.simulation.resource.scene.mapper.SystemScenePackageSublistMapper;
import com.css.simulation.resource.scene.mapper.SystemUserSceneMapper;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@Slf4j
@Service
public class SystemScenePackageService {

    @Resource
    private SystemScenePackageMapper systemScenePackageMapper;
    @Resource
    private SystemScenePackageSublistMapper systemScenePackageSublistMapper;
    @Resource
    private SystemUserSceneMapper systemUserSceneMapper;

    /**
     * 场景包录入
     */
    @SneakyThrows
    public void saveSystemScenePackage(SystemScenePackageNewPO params) {

        SystemScenePackagePO  po=new SystemScenePackagePO();
        po.setPackageName(params.getPackageName());
        po.setSceneDescribe(params.getSceneDescribe());
        String packId=StringUtil.getRandomUUID();
        po.setId(packId);
        po.setCreateTime(TimeUtil.getNowForMysql());
        po.setModifyTime(TimeUtil.getNowForMysql());
        po.setCreateUserId(AuthUtil.getCurrentUserId());
        po.setIsDeleted("0");
        //zr
        List<String> zrIds=params.getZrIds();
        if(ObjectUtil.isNotNull(zrIds)){
            List<SystemScenePackageSublistPO> zrList=new ArrayList<>();
            for (String id:zrIds) {
                SystemScenePackageSublistPO zrPo=new SystemScenePackageSublistPO();
                zrPo.setSublistId(StringUtil.getRandomUUID());
                zrPo.setSceneType("1");
                zrPo.setSceneId(id);
                zrPo.setSceneAndPackage(packId);
                zrPo.setCreateTime(TimeUtil.getNowForMysql());
                zrPo.setModifyTime(TimeUtil.getNowForMysql());
                zrPo.setCreateUserId(AuthUtil.getCurrentUserId());
                zrList.add(zrPo);
            }
            systemScenePackageSublistMapper.saveSystemScenePackageSublist(zrList);
        }
//zr
        List<String> bzIds=params.getBzIds();
        if(ObjectUtil.isNotNull(bzIds)){
            List<SystemScenePackageSublistPO> bzList=new ArrayList<>();
            for (String id:bzIds) {
                SystemScenePackageSublistPO bzPo=new SystemScenePackageSublistPO();
                bzPo.setSublistId(StringUtil.getRandomUUID());
                bzPo.setSceneType("2");
                bzPo.setSceneId(id);
                bzPo.setSceneAndPackage(packId);
                bzPo.setCreateTime(TimeUtil.getNowForMysql());
                bzPo.setModifyTime(TimeUtil.getNowForMysql());
                bzPo.setCreateUserId(AuthUtil.getCurrentUserId());
                bzList.add(bzPo);
            }
            systemScenePackageSublistMapper.saveSystemScenePackageSublist(bzList);
        }
        //zr
        List<String> jtIds=params.getJtIds();
        if(ObjectUtil.isNotNull(jtIds)){
            List<SystemScenePackageSublistPO> jtList=new ArrayList<>();
            for (String id:jtIds) {
                SystemScenePackageSublistPO jtPo=new SystemScenePackageSublistPO();
                jtPo.setSublistId(StringUtil.getRandomUUID());
                jtPo.setSceneType("3");
                jtPo.setSceneId(id);
                jtPo.setSceneAndPackage(packId);
                jtPo.setCreateTime(TimeUtil.getNowForMysql());
                jtPo.setModifyTime(TimeUtil.getNowForMysql());
                jtPo.setCreateUserId(AuthUtil.getCurrentUserId());
                jtList.add(jtPo);
            }
            systemScenePackageSublistMapper.saveSystemScenePackageSublist(jtList);
        }
        //zr
        List<String> fhIds=params.getFhIds();
        if(ObjectUtil.isNotNull(fhIds)){
            List<SystemScenePackageSublistPO> fhList=new ArrayList<>();
            for (String id:zrIds) {
                SystemScenePackageSublistPO fhPo=new SystemScenePackageSublistPO();
                fhPo.setSublistId(StringUtil.getRandomUUID());
                fhPo.setSceneType("4");
                fhPo.setSceneId(id);
                fhPo.setSceneAndPackage(packId);
                fhPo.setCreateTime(TimeUtil.getNowForMysql());
                fhPo.setModifyTime(TimeUtil.getNowForMysql());
                fhPo.setCreateUserId(AuthUtil.getCurrentUserId());
                fhList.add(fhPo);
            }
            systemScenePackageSublistMapper.saveSystemScenePackageSublist(fhList);
        }
        systemScenePackageMapper.saveSystemScenePackage(po);
    }
    //场景包列表
    @SneakyThrows
    public List<SystemScenePackageVO> querySystemScenePackageList(SystemScenePackageParam params) {
        List<SystemScenePackageVO> list = systemScenePackageMapper.querySystemScenePackageList(params);
        return list;
    }
    //编辑场景包
    @SneakyThrows
    public SystemScenePackageNewPO querySystemScenePackageById(SystemScenePackageParam params) {
        SystemScenePackageNewPO newPo=new SystemScenePackageNewPO();
        SystemScenePackagePO po = systemScenePackageMapper.querySystemScenePackageById(params);
        SystemScenePackageSublistPO sublistPo=new SystemScenePackageSublistPO();
        sublistPo.setSceneAndPackage(params.getId());
        sublistPo.setSceneType("1");
       List<String>  zrList=systemScenePackageSublistMapper.querySystemScenePackageSublistList(sublistPo);
        sublistPo.setSceneType("2");
        List<String>  bzList=systemScenePackageSublistMapper.querySystemScenePackageSublistList(sublistPo);
        sublistPo.setSceneType("3");
        List<String>  jtList=systemScenePackageSublistMapper.querySystemScenePackageSublistList(sublistPo);
        sublistPo.setSceneType("4");
        List<String>  fhList=systemScenePackageSublistMapper.querySystemScenePackageSublistList(sublistPo);
        BeanUtils.copyProperties(po, newPo);
        newPo.setZrIds(zrList);
        newPo.setBzIds(bzList);
        newPo.setJtIds(jtList);
        newPo.setFhIds(fhList);
        return newPo;
    }
    //编辑场景包
    @SneakyThrows
    public void updateSystemScenePackage(SystemScenePackageNewPO params) {
        SystemScenePackagePO  po=new SystemScenePackagePO();
        po.setPackageName(params.getPackageName());
        po.setSceneDescribe(params.getSceneDescribe());
        String packId=params.getId();
        po.setId(packId);
        //删除之前的子表
        SystemScenePackageSublistPO sublistPO=new SystemScenePackageSublistPO();
        sublistPO.setModifyTime(TimeUtil.getNowForMysql());
        sublistPO.setModifyUserId(AuthUtil.getCurrentUserId());
        sublistPO.setSceneAndPackage(packId);
        sublistPO.setIsDeleted("1");
        systemScenePackageSublistMapper.deleteSystemScenePackageSublist(sublistPO);
        //zr
        List<String> zrIds=params.getZrIds();
        if(ObjectUtil.isNotNull(zrIds)){
            List<SystemScenePackageSublistPO> zrList=new ArrayList<>();
            for (String id:zrIds) {
                SystemScenePackageSublistPO zrPo=new SystemScenePackageSublistPO();
                zrPo.setSublistId(StringUtil.getRandomUUID());
                zrPo.setSceneType("1");
                zrPo.setSceneId(id);
                zrPo.setSceneAndPackage(packId);
                zrPo.setCreateTime(TimeUtil.getNowForMysql());
                zrPo.setModifyTime(TimeUtil.getNowForMysql());
                zrPo.setCreateUserId(AuthUtil.getCurrentUserId());
                zrList.add(zrPo);
            }
            systemScenePackageSublistMapper.saveSystemScenePackageSublist(zrList);
        }
//zr
        List<String> bzIds=params.getBzIds();
        if(ObjectUtil.isNotNull(bzIds)){
            List<SystemScenePackageSublistPO> bzList=new ArrayList<>();
            for (String id:bzIds) {
                SystemScenePackageSublistPO bzPo=new SystemScenePackageSublistPO();
                bzPo.setSublistId(StringUtil.getRandomUUID());
                bzPo.setSceneType("2");
                bzPo.setSceneId(id);
                bzPo.setSceneAndPackage(packId);
                bzPo.setCreateTime(TimeUtil.getNowForMysql());
                bzPo.setModifyTime(TimeUtil.getNowForMysql());
                bzPo.setCreateUserId(AuthUtil.getCurrentUserId());
                bzList.add(bzPo);
            }
            systemScenePackageSublistMapper.saveSystemScenePackageSublist(bzList);
        }
        //zr
        List<String> jtIds=params.getJtIds();
        if(ObjectUtil.isNotNull(jtIds)){
            List<SystemScenePackageSublistPO> jtList=new ArrayList<>();
            for (String id:jtIds) {
                SystemScenePackageSublistPO jtPo=new SystemScenePackageSublistPO();
                jtPo.setSublistId(StringUtil.getRandomUUID());
                jtPo.setSceneType("3");
                jtPo.setSceneId(id);
                jtPo.setSceneAndPackage(packId);
                jtPo.setCreateTime(TimeUtil.getNowForMysql());
                jtPo.setModifyTime(TimeUtil.getNowForMysql());
                jtPo.setCreateUserId(AuthUtil.getCurrentUserId());
                jtList.add(jtPo);
            }
            systemScenePackageSublistMapper.saveSystemScenePackageSublist(jtList);
        }
        //zr
        List<String> fhIds=params.getFhIds();
        if(ObjectUtil.isNotNull(fhIds)){
            List<SystemScenePackageSublistPO> fhList=new ArrayList<>();
            for (String id:zrIds) {
                SystemScenePackageSublistPO fhPo=new SystemScenePackageSublistPO();
                fhPo.setSublistId(StringUtil.getRandomUUID());
                fhPo.setSceneType("4");
                fhPo.setSceneId(id);
                fhPo.setSceneAndPackage(packId);
                fhPo.setCreateTime(TimeUtil.getNowForMysql());
                fhPo.setModifyTime(TimeUtil.getNowForMysql());
                fhPo.setCreateUserId(AuthUtil.getCurrentUserId());
                fhList.add(fhPo);
            }
            systemScenePackageSublistMapper.saveSystemScenePackageSublist(fhList);
        }

        po.setModifyTime(TimeUtil.getNowForMysql());
        po.setModifyUserId(AuthUtil.getCurrentUserId());
        systemScenePackageMapper.updateSystemScenePackage(po);
    }
    //删除场景包
    @SneakyThrows
    public void deleteSystemScenePackage(SystemScenePackagePO params) {
        params.setIsDeleted("1");
        params.setModifyTime(TimeUtil.getNowForMysql());
        params.setModifyUserId(AuthUtil.getCurrentUserId());
        systemScenePackageMapper.deleteSystemScenePackage(params);
    }
    //根据场景包查询配置账号
    @SneakyThrows
    public SystemUserSceneVO queryUserByPackageId(SystemScenePackageNewPO params) {
        SystemUserSceneVO VO=new SystemUserSceneVO();
        List<UserSceneVO> userIds=systemUserSceneMapper.queryUserByPackageId(params.getId());
        VO.setPackageId(params.getId());
        VO.setUserIds(userIds);
        return VO;
    }

    //根据场景包添加配置账号
    @SneakyThrows
    public void saveUserByPackageId(SystemUserSceneVO params) {
        List<UserSceneVO> listVo=params.getUserIds();
        List<SystemUserScenePO>  list=new ArrayList<>();
        for (UserSceneVO vo:listVo){
            SystemUserScenePO po=new SystemUserScenePO();
            po.setPackageId(params.getPackageId());
            po.setId(StringUtil.getRandomUUID());
            po.setCreateTime(TimeUtil.getNowForMysql());
            po.setModifyTime(TimeUtil.getNowForMysql());
            po.setCreateUserId(AuthUtil.getCurrentUserId());
            po.setIsDeleted("0");
            po.setUserId(vo.getUserId());
            list.add(po);
        }
        systemUserSceneMapper.saveSystemUserScene(list);
    }
    //根据场景包删除配置账号
    @SneakyThrows
    public void deleteUserByPackageId(SystemUserSceneVO params) {
        List<UserSceneVO> listVo=params.getUserIds();
        for (UserSceneVO vo:listVo){
            SystemUserScenePO po=new SystemUserScenePO();
            po.setPackageId(params.getPackageId());
            po.setModifyTime(TimeUtil.getNowForMysql());
            po.setModifyUserId(AuthUtil.getCurrentUserId());
            po.setIsDeleted("0");
            po.setUserId(vo.getUserId());
            systemUserSceneMapper.deleteSystemUserScene(po);

        }
    }

    //场景分配时场景包的列表
    @SneakyThrows
    public  List<Map> queryPackageList( ) {
        List<Map> list=systemScenePackageMapper.queryPackageList();
        return list;
    }


    //根据配置账号添加场景包
    @SneakyThrows
    public void savePackageByUserId(SystemUserSceneVO params) {
        List<PackageVO> listVo=params.getPackageList();
        List<SystemUserScenePO>  list=new ArrayList<>();
        for (PackageVO vo:listVo){
            SystemUserScenePO po=new SystemUserScenePO();
            po.setPackageId(vo.getPackageId());
            po.setId(StringUtil.getRandomUUID());
            po.setCreateTime(TimeUtil.getNowForMysql());
            po.setModifyTime(TimeUtil.getNowForMysql());
            po.setCreateUserId(AuthUtil.getCurrentUserId());
            po.setIsDeleted("0");
            po.setUserId(params.getUserId());
            list.add(po);
        }
        systemUserSceneMapper.saveSystemUserScene(list);
    }

    //根据场景包删除配置账号
    @SneakyThrows
    public void deletePackageByUserId(SystemUserSceneVO params) {
        List<PackageVO> listVo=params.getPackageList();
        for (PackageVO vo:listVo){
            SystemUserScenePO po=new SystemUserScenePO();
            po.setPackageId(vo.getPackageId());
            po.setModifyTime(TimeUtil.getNowForMysql());
            po.setModifyUserId(AuthUtil.getCurrentUserId());
            po.setIsDeleted("0");
            po.setUserId(params.getUserId());
            systemUserSceneMapper.deleteSystemUserScene(po);

        }
    }

    //配置人员场景包列表
    @SneakyThrows
    public List<SystemScenePackageVO> queryPackageByUserIdList(SystemScenePackageParam params) {
        List<SystemScenePackageVO> list = systemScenePackageMapper.queryPackageByUserIdList(params);
        return list;
    }
}
