package com.css.simulation.resource.system.ctrl;

import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.param.system.UserParam;
import api.common.pojo.po.system.UserPO;
import api.common.pojo.vo.system.UserVO;
import api.common.util.ObjectUtil;
import com.css.simulation.resource.system.service.UserService;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;


@Controller()
@RequestMapping("/user")
public class UserCtrl {

    @Autowired
    UserService userService;

    /**
     * 获取当前登录人详情
     */
    @RequestMapping("/getCurrentUserInfo")
    @ResponseBody
    public ResponseBodyVO getCurrentUserInfo() {
        ResponseBodyVO<UserVO> response = new ResponseBodyVO<UserVO>(ResponseBodyVO.Response.SUCCESS);
        response.setInfo(userService.getCurrentUserInfo());
        return response;
    }

    /**
     * 获取人员列表
     */
    @RequestMapping("/getUserPageList")
    @ResponseBody
    public ResponseBodyVO<PageInfo<UserVO>> getUserPageList(@RequestBody UserParam pageParam){
        ResponseBodyVO<PageInfo<UserVO>> response = new ResponseBodyVO<PageInfo<UserVO>>(ResponseBodyVO.Response.SUCCESS);
        response.setInfo(userService.getUserPageList(pageParam));
        return response;
    }

    /**
     * 新增、修改
     */
    @RequestMapping("/saveUser")
    @ResponseBody
    public ResponseBodyVO<UserPO> saveUser(@RequestBody UserPO userPO) throws Exception {
        if(ObjectUtil.isNull(userPO)){
            return new ResponseBodyVO(false, 400, "参数必传！",null);
        }
        ResponseBodyVO<UserPO> response = new ResponseBodyVO<UserPO>(ResponseBodyVO.Response.SUCCESS);
        userPO = userService.saveUser(userPO);
        if(ObjectUtil.isNull(userPO)){
            return new ResponseBodyVO(false, 400, "没有创建账户的权限！",null);
        }
        if(ObjectUtil.isNull(userPO.getId())){
            return new ResponseBodyVO(false, 400, "账户名重复！",null);
        }
        response.setInfo(userPO);
        return response;
    }

    /**
     * 人员密码重置
     */
    @RequestMapping("/saveDefaultPassword")
    @ResponseBody
    public ResponseBodyVO saveDefaultPassword(@RequestBody UserPO userPO) throws Exception {
        if(ObjectUtil.isNull(userPO)){
            return new ResponseBodyVO(false, 400, "参数必传！",null);
        }
        if(ObjectUtil.isNull(userPO.getId())){
            return new ResponseBodyVO(false, 400, "参数必传！",null);
        }
        userService.saveDefaultPassword(userPO);
        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS);
    }

    /**
     * 启用/停用账户
     */
    @RequestMapping("/saveVisible")
    @ResponseBody
    public ResponseBodyVO saveVisible(@RequestBody UserPO userPO) throws Exception {
        if(ObjectUtil.isNull(userPO)){
            return new ResponseBodyVO(false, 400, "参数必传！",null);
        }
        if(ObjectUtil.isNull(userPO.getId()) || ObjectUtil.isNull(userPO.getVisible())){
            return new ResponseBodyVO(false, 400, "参数必传！",null);
        }
        userService.saveVisible(userPO);
        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS);
    }
}
