package com.css.simulation.resource.system.service;

import api.common.pojo.constants.DictConstants;
import api.common.pojo.constants.LogConstants;
import api.common.pojo.param.system.ClusterParam;
import api.common.pojo.po.system.ClusterPO;
import api.common.pojo.vo.system.ClusterVO;
import api.common.util.ObjectUtil;
import api.common.util.StringUtil;
import com.css.simulation.resource.common.utils.AuthUtil;
import com.css.simulation.resource.common.utils.PageUtil;
import com.css.simulation.resource.common.utils.PoUtil;
import com.css.simulation.resource.log.service.LogService;
import com.css.simulation.resource.system.mapper.ClusterMapper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


@Service
public class ClusterService {

    @Autowired
    ClusterMapper clusterMapper;

    @Autowired
    LogService logService;

    @Autowired
    DictService dictService;


    public PageInfo<ClusterVO> getClusterList(ClusterParam clusterParam) {
        PageUtil.setPageInfo(clusterParam);
        String roleCode = AuthUtil.getCurrentUserRoleCode();
        String useType = AuthUtil.getCurrentUseType();
        //当前账户为管理员账户，需要查询普通账户，设置roleCode为2
        if(DictConstants.ROLE_CODE_ADMIN.equals(roleCode) || DictConstants.ROLE_CODE_SYSADMIN.equals(roleCode)){
            clusterParam.setRoleCode(DictConstants.ROLE_CODE_UESR);
        }else if(DictConstants.ROLE_CODE_UESR.equals(roleCode) && DictConstants.USE_TYPE_EXCLUSIVE.equals(useType)){
            // 当前账户为独占使用的普通账户，需要查询该账户创建的普通账户子账户，设置roleCode为3及当前创建用户id
            clusterParam.setRoleCode(DictConstants.ROLE_CODE_SUBUESR);
        }else{
            return new PageInfo<>(new ArrayList<>());
        }
        List<ClusterVO> list = clusterMapper.getClusterList(clusterParam);
        for (ClusterVO vo:list){
            Map<String, String> dictMapByType = dictService.getDictMapByType(DictConstants.USE_TYPE);
            vo.setUseType(dictMapByType.get(vo.getUseType()));
        }
        return new PageInfo<>(list);
    }


    public ClusterPO saveCluster(ClusterPO clusterPO) {
        String id = clusterPO.getId();
        if(ObjectUtil.isNotNull(id)){
            // 更新，将原纪录is_deleted置为1
            ClusterPO deleteClusterPo = new ClusterPO();
            deleteClusterPo.setId(id);
            PoUtil.initDelPo(deleteClusterPo);
            clusterMapper.deleteById(deleteClusterPo);
        }
        clusterPO.setId(StringUtil.getRandomUUID());
        PoUtil.initAddPo(clusterPO);
        clusterMapper.insert(clusterPO);
        logService.logCluster(LogConstants.SYS_LOG_CLUSTER_INSERT, clusterPO);
        return clusterPO;
    }


    public PageInfo<ClusterVO> getClusterHistory(ClusterParam clusterParam) {
        PageUtil.setPageInfo(clusterParam);
        List<ClusterVO> list = clusterMapper.getClusterHistory(clusterParam);
        return new PageInfo<>(list);
    }


    public HashMap<String, Integer> getClusterNum() {

        ClusterParam clusterParam = new ClusterParam();
        String roleCode = AuthUtil.getCurrentUserRoleCode();
        String useType = AuthUtil.getCurrentUseType();
        //当前账户为管理员账户，需要查询普通账户，设置roleCode为2
        if(DictConstants.ROLE_CODE_ADMIN.equals(roleCode) || DictConstants.ROLE_CODE_SYSADMIN.equals(roleCode)){
            clusterParam.setRoleCode(DictConstants.ROLE_CODE_UESR);
        }else if(DictConstants.ROLE_CODE_UESR.equals(roleCode) && DictConstants.USE_TYPE_EXCLUSIVE.equals(useType)){
            // 当前账户为独占使用的普通账户，需要查询该账户创建的普通账户子账户，设置roleCode为3及当前创建用户id
            clusterParam.setRoleCode(DictConstants.ROLE_CODE_SUBUESR);
        }else{
            return null;
        }

        HashMap<String, Integer> resMap = clusterMapper.getClusterNum(clusterParam);
        return resMap;
    }


    public Integer getLicenseNum(){
        String roleCode = AuthUtil.getCurrentUserRoleCode();
        String useType = AuthUtil.getCurrentUseType();
        String userId = AuthUtil.getCurrentUserId();
        if(DictConstants.ROLE_CODE_ADMIN.equals(roleCode) || DictConstants.ROLE_CODE_SYSADMIN.equals(roleCode)){ //管理员账户
            return -1;
        }else if(DictConstants.ROLE_CODE_SUBUESR.equals(roleCode) && DictConstants.USE_TYPE_PUBLIC.equals(useType)){
            //查询父账户
            userId = AuthUtil.getCreateUserId();
        }
        Integer simulationLicenseNum = clusterMapper.getLicenseNum(userId);
        if(simulationLicenseNum == null){
            simulationLicenseNum = 0;
        }
        return simulationLicenseNum;
    }
}
