package com.css.simulation.resource.system.service;

import api.common.pojo.constants.DictConstants;
import api.common.pojo.constants.LogConstants;
import api.common.pojo.param.system.ParameterParam;
import api.common.pojo.po.system.ParameterPO;
import api.common.pojo.vo.system.ParameterVO;
import api.common.util.ObjectUtil;
import api.common.util.StringUtil;
import com.css.simulation.resource.common.utils.AuthUtil;
import com.css.simulation.resource.common.utils.PageUtil;
import com.css.simulation.resource.common.utils.PoUtil;
import com.css.simulation.resource.log.service.LogService;
import com.css.simulation.resource.system.mapper.ParameterMapper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;


@Service
public class ParameterService {

    @Autowired
    ParameterMapper parameterMapper;

    @Autowired
    LogService logService;


    public PageInfo<ParameterVO> getParameterList(ParameterParam pageParam) {
        PageUtil.setPageInfo(pageParam);
        List<ParameterVO> list = parameterMapper.getParameterList(pageParam);
        return new PageInfo<>(list);
    }

    public ParameterPO saveParameter(ParameterPO paramPO) {
        String id = paramPO.getId();
        if(ObjectUtil.isNotNull(id)){
            // 更新，将原纪录is_deleted置为1
            ParameterPO deleteParamPo = new ParameterPO();
            deleteParamPo.setId(id);
            PoUtil.initDelPo(deleteParamPo);
            parameterMapper.deleteById(deleteParamPo);
        }
        //新增一条纪录
        paramPO.setId(StringUtil.getRandomUUID());
        PoUtil.initAddPo(paramPO);
        parameterMapper.insert(paramPO);
        logService.logParameter(LogConstants.SYS_LOG_PARAM_INSERT, paramPO);
        return paramPO;
    }

    public PageInfo<ParameterVO> getParamHistory(ParameterParam pageParam) {
        PageUtil.setPageInfo(pageParam);
        List<ParameterVO> list = parameterMapper.getParamHistory(pageParam);
        return new PageInfo<>(list);
    }

    public HashMap<String, Integer> getSceneParam(){
        String roleCode = AuthUtil.getCurrentUserRoleCode();
        String userId = AuthUtil.getCurrentUserId();
        if(DictConstants.ROLE_CODE_ADMIN.equals(roleCode) || DictConstants.ROLE_CODE_SYSADMIN.equals(roleCode)){ //管理员账户
            return null;
        }else if(DictConstants.ROLE_CODE_SUBUESR.equals(roleCode)){
            //查询父账户
            userId = AuthUtil.getCreateUserId();
        }
        HashMap<String, Integer> sceneParam = parameterMapper.getSceneParam(userId);

        return sceneParam;
    }

}
