package com.css.simulation.resource.system.service;

import api.common.pojo.constants.DictConstants;
import api.common.pojo.constants.LogConstants;
import api.common.pojo.param.system.UserParam;
import api.common.pojo.po.system.UserPO;
import api.common.pojo.vo.system.UserVO;
import api.common.util.EncryptUtil;
import api.common.util.ObjectUtil;
import api.common.util.StringUtil;
import com.css.simulation.resource.common.oauth.OauthParameter;
import com.css.simulation.resource.common.utils.AuthUtil;
import com.css.simulation.resource.common.utils.PageUtil;
import com.css.simulation.resource.common.utils.PoUtil;
import com.css.simulation.resource.log.service.LogService;
import com.css.simulation.resource.system.mapper.UserMapper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.security.NoSuchAlgorithmException;
import java.util.List;
import java.util.Map;


@Service
public class UserService {

    @Autowired
    UserMapper userMapper;

    @Autowired
    OauthParameter oauthParameter;

    @Autowired
    LogService logService;

    @Autowired
    DictService dictService;

    public UserVO getCurrentUserInfo() {
        String userId = AuthUtil.getCurrentUserId();
        UserVO userVO = userMapper.getUserInfo(userId);
        return userVO;
    }

    public PageInfo<UserVO> getUserPageList(UserParam pageParam) {
        PageUtil.setPageInfo(pageParam);
        List<UserVO> list = null;
        String currentUserRoleCode = AuthUtil.getCurrentUserRoleCode();
        if(DictConstants.ROLE_CODE_SYSADMIN.equals(currentUserRoleCode)){//超级管理员
            list = userMapper.getUserPageLista(pageParam);
        }else if(DictConstants.ROLE_CODE_ADMIN.equals(currentUserRoleCode)){//子管理员
            list = userMapper.getUserPageListb(pageParam);
        }else if(DictConstants.ROLE_CODE_UESR.equals(currentUserRoleCode)){//普通用户
            //只查询自己创建的子账户
            pageParam.setCreateUserId(AuthUtil.getCurrentUserId());
            list = userMapper.getUserPageListc(pageParam);
        }else{
            return null;
        }
        //字典翻译
        Map<String, Map<String, String>> dictMaps = dictService.getDictMapsByTypes(DictConstants.ROLE_CODE);
        list.forEach(po ->{
            po.setRoleCode(dictMaps.get(DictConstants.ROLE_CODE).get(po.getRoleCode()));
        });
        return new PageInfo<>(list);
    }

    public UserPO saveUser(UserPO userPO) throws NoSuchAlgorithmException {
        //权限校验
        String currentUserRoleCode = AuthUtil.getCurrentUserRoleCode();
        if(DictConstants.ROLE_CODE_SYSADMIN.equals(currentUserRoleCode)){//超级管理员
            if(DictConstants.ROLE_CODE_ADMIN.equals(userPO.getRoleCode())){
                userPO.setRoleCode(DictConstants.ROLE_CODE_ADMIN);
            }else{
                userPO.setRoleCode(DictConstants.ROLE_CODE_UESR);
            }
        }else if(DictConstants.ROLE_CODE_ADMIN.equals(currentUserRoleCode)){//子管理员
            userPO.setRoleCode(DictConstants.ROLE_CODE_UESR);
        }else if(DictConstants.ROLE_CODE_UESR.equals(currentUserRoleCode)){//普通用户
            userPO.setRoleCode(DictConstants.ROLE_CODE_SUBUESR);
        }else{
            return null;
        }
        //重名校验
        List<UserPO> list = userMapper.checkUsername(userPO);
        if(ObjectUtil.isNotNull(list)){
            userPO.setId(null);
            return userPO;
        }
        PoUtil.initAddPo(userPO);
        String id = userPO.getId();
        if(ObjectUtil.isNull(id)){//新增
            userPO.setId(StringUtil.getRandomUUID());
            //初始密码
            userPO.setPassword(EncryptUtil.getLowerMD5(oauthParameter.getSimulationDefaultPassword()));
            userPO.setVisible("1");
            userMapper.insert(userPO);
            logService.logUser(LogConstants.SYS_LOG_USER_INSERT,userPO);
        }else{
            userMapper.update(userPO);
            logService.logUser(LogConstants.SYS_LOG_USER_UPDATE,userPO);
        }
        //密码清空
        userPO.setPassword(null);
        return userPO;
    }

    public void saveDefaultPassword(UserPO userPO) throws NoSuchAlgorithmException {
        userPO.setPassword(EncryptUtil.getLowerMD5(oauthParameter.getSimulationDefaultPassword()));
        PoUtil.initUpdatePo(userPO);
        userMapper.saveDefaultPassword(userPO);
        logService.logUser(LogConstants.SYS_LOG_USER_RESET,userPO);
    }

    public void saveVisible(UserPO userPO) {
        PoUtil.initUpdatePo(userPO);
        userMapper.saveVisible(userPO);
        if("1".equals(userPO.getVisible())){
            logService.logUser(LogConstants.SYS_LOG_USER_START,userPO);
        }else{
            logService.logUser(LogConstants.SYS_LOG_USER_STOP,userPO);
        }

    }
}
